/*******************************************************************************
RETURNS TO EDUCATION AND EXPERIENCE
Bradley Larson (BLarson@worldbank.org)
Graph returns to additional year of education from Montenegro and Patrinos 2014
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
IMPORT DATA
*******************************************************************************/

***	import returns to education data from Claudio Montenegro
	use "${data}/Montenegro and Patrinos 2017.dta", clear
	rename educy returns_education
	rename ccode code
	keep code year model returns_education
	replace returns_education=100*returns_education
	merge m:1 code using "${data}/class", keepusing(country) nogen keep(3)
	tempfile returns
	save `returns', replace

/*******************************************************************************
PREP DATA
*******************************************************************************/

***	collapse data to average surveys given in same year in a given country
	use `returns', clear
	replace model="1" if model=="FEMALE"
	replace model="2" if model=="MALE"
	replace model="3" if model=="ALL"
	destring model, replace
	sum returns_education
	collapse (mean) returns_education, by(country year model)
	label define model 1 "female" 2 "male" 3 "total"
	label val model model
	tab model, sum(returns_education)
	
***	keep only the latest
	bysort country: egen maxyr=max(year)
	keep if year==maxyr
	drop maxyr
	sum returns_education
	
***	merge with classification data
	replace country="Sao Tome and Principe" if country=="São Tomé and Principe"
	replace country="Cote d'Ivoire"			if country=="Côte d'Ivoire"
	merge m:1 country using "${data}/class" , keep(3) nogen keepusing(country code category)
	label var returns_education "Returns to Education (Montenegro and Patrinos 2004)"
	compress _all
	tempfile working
	
***	pull year
	sum year
	local minyr = `r(min)'
	local maxyr = `r(max)'

***	fix names and save temp
	rename model gender
	tempfile working
	save `working'
	
***	collapse by region and gender
		
	*** collapse for categories
		use `working', clear
		collapse (median) returns_education, by(category gender)
		tempfile cats
		save `cats'
		
	***	collapse for world total
		use `working', clear
		collapse (median) returns_education, by(gender)
		append using `cats'
		save `working', replace
		
		
***	fix labels
	rename returns_education returns
	decode gender, gen(gen)
	decode category, gen(cat)
	replace cat="World" if category==.
	sum category
	local worldcatnum=`r(max)'+1 
	replace category=`worldcatnum' if category==.
	local catlabname: value label category
	lab def `catlabname' `worldcatnum' "World", modify
	save `working', replace
	
***	generate sort variable
	keep if gender==1
	drop if category==7 | category==8
	gsort -returns
	gen sort=_n
	keep sort category
	merge 1:m category using `working', nogen
	sum sort
	replace sort=`r(max)'+1 if category==7
	replace sort=`r(max)'+2 if category==8
	save `working', replace
	
***	drop extranneous data
	drop if gender==3
	drop gender category
	save `working', replace
	
*** reshape wide
	reshape wide returns, i(cat) j(gen) str
	rename returns* *

***	encode regions
	egen category= axis(sort), label(cat)
		
***	split the string variable used to label
	splitstring cat

***	loop for labels
	levelsof category, local(categories)
	sort category
	foreach category of local categories {
		local l1 =strtrim("`=cat_line1[`category']'")
		local l2 =strtrim("`=cat_line2[`category']'")
		local relabel `relabel' `category' `""`l1'" "`l2'""'
		}

***	archive data
	preserve
	keep cat female male
	rename cat category
	lab var category "Country category"
	lab var female "Median wage increases for females associated with each additional year of schooling"
	lab var male "Median wage increases for males associated with each additional year of schooling"
	wdrarchive
	restore

/*******************************************************************************
GRAPH 
*******************************************************************************/
		
***	reference graph to ensure accurate wrapped titles
		sort category
		graph bar female male ,  ///
		over(category, label(alternate)) ///
			graphregion(c(white)lc(white)lw(thick)) ///
			ylabel(0(4)16, angle(h) glc(gs12) glw(vthin) notick) ///
			yscale(noline) ///
		legend( ///
		label(1 "Female") ///
		label(2 "Male") /// 		label(3 "Total") ///
		region(c(none)) bexpand ///
		symx(5) symy(5) ///
		r(1) ///
		) ///
		bar(1 , col("$wdrscheme3") ) ///
		bar(2 , col("$wdrscheme2") ) /// 		
			xsize(6.5) ysize(3) ///
		name(native_labels)
			
***	graph with custom wrapped labels	
	sort category
	graph bar female male ,  /// total
		over(category, relabel(`relabel') ) ///
			graphregion(c(white)lc(white)lw(thick)) ///
			ylabel(0(4)16, angle(h) glc(gs2) glw(thin) glp(shortdash) notick) ///
			yscale(noline) ///
		ytitle("Percent") ///
		legend( ///
		label(1 "Female") ///
		label(2 "Male") ///		
		region(c(none)) bexpand ///
		symx(5) symy(5) ///
		r(1) ///
		) ///
		bar(1 , col("$wdrscheme3") ) ///
		bar(2 , col("$wdrscheme2") ) /// 		
			xsize(6.5) ysize(3) ///
		name(re_labels)

/*******************************************************************************
EXPORT
*******************************************************************************/	
		
	wdrexport , ///
		title(More schooling is systematically associated with higher wages) ///
		subtitle(Median percentage increase in wages associated with each additional year of schooling, by country group and gender) ///
		source(WDR 2018 team, using data from Montenegro and Patrinos (2017).) ///
		note(Latest available data, `minyr'-`maxyr'. Regions do not include high-income countries.) ///
		chapter(1) figure(1)

exit
