/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education

Figure 1.5 What matters for growth is learning
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
LOAD AND MANIPULATE DATA
*******************************************************************************/	
	
***	import data
	use "${data}/Hanushek and Woessmann 2012 and WDI 2017", clear

***	choose start year and end year for analysis
	local maxyr 2015
	local minyr 1970
	
***	log initial income per capita
	foreach income in gni gdp {
		gen ln_`income'_pc`minyr' =ln(`income'_pc`minyr')
		}

***	rename GDP to standard income measure
	rename gdp_econgrowth econgrowth
	rename gdp_growthrate growthrate
	
***	trim data
	reg econgrowth ln_gdp_pc`minyr' ave_yrs_school hw_score  // determine the countries that have all necessary data, so we have a single, comparable sample
	gen reg_flag=e(sample)
	noi di _newline(3) "these countries do not have the requisite data:"
	noi list reg_flag country code econgrowth ln_gdp_pc1970 ave_yrs_school hw_score if reg_flag==0, clean noo 
	noi di _newline(3) "these countries have the requisite data:"
	noi list reg_flag country code econgrowth ln_gdp_pc1970 ave_yrs_school hw_score if reg_flag==1, clean noo 
	keep if reg_flag==1
	drop if code=="BWA" // drop countries that don't make sense according to Deon
	drop if code=="ZWE" // drop countries that don't make sense according to Deon
	
***	find tests scores and growth conditional on initial GDP per capita and years of schooling/test scores
	foreach yvar in ave_yrs_school hw_score adm_score econgrowth growthrate {
		foreach xvar in ave_yrs_school hw_score adm_score {
			reg `yvar' `xvar' ln_gdp_pc1970
			predict `yvar'_`xvar', residuals
			label var `yvar'_`xvar' "`yvar' conditional on initial GDPpc and `xvar'"
			}
		}

***	archive data: panel 1
	preserve
	keep country code growthrate_ave_yrs_school	hw_score_ave_yrs_school	
	order country code growthrate_ave_yrs_school hw_score_ave_yrs_school 
	lab var country "Country"
	lab var code "Country code" 
	lab var growthrate_ave_yrs_school "Growth rate given initial GDP per capita and average years of schooling"
	lab var hw_score_ave_yrs_school "Test scores given initial GDP per capita and average years of schooling"
	rename growthrate_ave_yrs_school growth_school
	rename hw_score_ave_yrs_school scores_school
	wdrarchive, title(Test scores and growth)
	restore

***	archive data: panel 2
	preserve
	keep country code growthrate_hw_score ave_yrs_school_hw_score
	lab var country "Country"
	lab var code "Country code" 
	lab var ave_yrs_school_hw_score "Years of schooling given initial GDP per capita and test scores"
	lab var growthrate_hw_score "Growth rate given initial GDP per capita and test scores"
	rename ave_yrs_school_hw_score school_scores
	rename growthrate_hw_score growth_scores
	order country code growth_scores  school_scores
	wdrarchive, title(Years of schooling and growth)
	restore

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set graph options
	local lopts lc("${wdrscheme2}") lw(medthick)
	local mopts mc("${wdrscheme5}") m(o)
	local gopts legend(off)  ///
				graphregion(c(white)lc(white)lw(thick)) ///
				aspectratio(1) ///
				ylabel(,nogrid angle(h)) ///
				yline(0, lc(gs8) lp(shortdash) lw(thin)) ///
				xline(0, lc(gs8) lp(shortdash) lw(thin)) 
	local topts	bexpand just(left) size(medsmall) color(black) margin(l-4)
	local sopts	bexpand just(left) size(medsmall) color(black) margin(l-4 t-1 b+1)	
	
***	LABEL VARS
	ds hw_score* adm_score*
	foreach var in `r(varlist)' {
		label var `var' "Test scores"
		}
	ds ave_yrs_school*
	foreach var in `r(varlist)' {
		label var `var' "Years of schooling"
		}
	ds growthrate*
	foreach var in `r(varlist)' {
		label var `var' "Annual GDP per capita growth (%)"
		}
	
***	graph for chosen scores	
	
	foreach test in hw_score   {  
		***	a. left panel 
			***	regress for labels
				reg growthrate_ave_yrs_school	`test'_ave_yrs_school
					local r2 	: di %3.2f `e(r2)'
					local b 	: di %3.2f _b[`test'_ave_yrs_school]
					local cons 	: di %3.2f _b[_cons]
					local t		: di %3.2f _b[`test'_ave_yrs_school]/_se[`test'_ave_yrs_school]
					local absb	: di %03.2f abs(`b')
					if `b'>=0 {
					local sgnb "+"
					}
					else {
					local sgnb "-"
					}
				local graphstats	"y = `cons' `sgnb' `absb'x" "t = `t'" "R{super:2} = `r2'"
										
			***	graph
				local xttl : var label `test'_ave_yrs_school
				local yttl : var label growthrate_ave_yrs_school
				twoway ///
					(lfit 		growthrate_ave_yrs_school	`test'_ave_yrs_school										, `lopts') ///
					(scatter	growthrate_ave_yrs_school	`test'_ave_yrs_school 	if growthrate_ave_yrs_school <4	, `mopts') ///
					, ///
						xtitle("`xttl'") ///
						ytitle("`yttl'") ///
						`gopts' ///
						title("{bf:a. Test scores and growth}", `topts') ///
						subtitle("    {it:conditional on intitial GDP per capita and}" "    {it:years of schooling}", `sopts') ///
						note("`graphstats'"		, ring(0) pos(5) size(small)  just(left) c(black) ) ///
						name(a_`test')
					
		*** b. right panel 
			***	regress for labels
				reg growthrate_`test' ave_yrs_school_`test'
					local r2 	: di %3.2f `e(r2)'
					local b 	: di %3.2f _b[ave_yrs_school_`test']
					local cons 	: di %3.2f _b[_cons]
					local t		: di %3.2f _b[ave_yrs_school_`test']/_se[ave_yrs_school_`test']
					local absb	: di %03.2f abs(`b')
					if `b'>=0 {
					local sgnb "+"
					}
					else {
					local sgnb "-"
					}
					local graphstats	"y = `cons' `sgnb' `absb'x" "t = `t'" "R{super:2} = `r2'"
			***	graph
				local xttl : var label ave_yrs_school_`test'
				local yttl : var label growthrate_`test' 
					twoway ///
						(lfit 		growthrate_`test' ave_yrs_school_`test', `lopts') ///
						(scatter	growthrate_`test' ave_yrs_school_`test', `mopts') ///
						, ///
						xtitle("`xttl'") ///
						ytitle("`yttl'") ///
						title("{bf:b. Years of schooling and growth}", `topts' ) ///
						subtitle("    {it:conditional on the log of intitial GDP per capita}" "    {it:and test scores}", `sopts') ///
						note("`graphstats'"		, ring(0) pos(5) size(small)  just(left) c(black)) ///
						`gopts' ///
						name(b_`test')
		
	***	combine panels a and b
	
		graph combine a_`test' b_`test', name(`test'_combo, replace) ycommon graphregion(c(white)lc(white)lw(thick)margin(l-6 r-5 b-5 t-5)) xsize(6.5) ysize(3.5) scale(1.35)
		graph drop a_`test' b_`test'
		}
		
/*******************************************************************************
EXPORT 
*******************************************************************************/
	wdrexport , ///
		title(What matters for growth is learning) ///
		subtitle(Annual average per capita growth in GDP, 1970-2015, conditional on test scores, years of schooling completed, and initial GDP per capita) ///
		source(WDR 2018 team, using data from Hanushek and Woessmann (2012) and the World Bank’s World Development Indicators (database), 2017.) ///
		chapter(1) figure(5)

    exit

