/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education

Mekko plot of Lee and Lee 2016
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA 
*******************************************************************************/

***	load and trim data
	use "$data/Lee and Lee 2016 education stock", clear
	keep if year==2010
	keep if sex=="MF"
	
***	sort out country categories
	decode region, gen(category)
	decode incomegroup, gen(aux_category)
	replace category=aux_category if incomegroup==4
	
***	determine sort order for x-axis
	gen sortorder=region
	sum sortorder
	replace sortorder =`r(max)'+1 if incomegroup==4
	tempfile mekkoworking
	save `mekkoworking'
	
***	reassign categoriy numbers, since we have no North America (category 5)
	keep  category sortorder
	duplicates drop
	sort sortorder
	drop if sortorder==.
	replace sortorder=_n
	levelsof sortorder, local(sorts)
	foreach sort of local sorts {
		local vallab `vallab' `sort' "`=category[`sort']'"
		}
	rename sortorder mekkocat
	label define mekkocat `vallab'
	label val mekkocat mekkocat
	merge 1:m category using `mekkoworking', keep(3) nogen
	save `mekkoworking', replace
	
***	collapse data, weighting by country population
	use `mekkoworking', clear
	collapse (mean) lu lp ls lh [aw=pop], by(mekkocat)
	tempfile mekko
	save `mekko'
	
***	merge with new category numbers/labels
	use `mekkoworking', clear
	collapse (sum) pop, by(mekkocat)
	merge 1:1 mekkocat using `mekko', nogen
	save `mekko', replace
	
***	replace counts with percentages
	egen tots =rowtotal(lu lp ls lh)
	foreach var in lu lp ls lh {
		replace `var' = `var'/tots
		}
		
***	reshape long
	reshape long l, i(mekkocat) j(attain)	 str
	gen attainpop = pop*l
	
***	recode attainment values, so that they're in order	
	encode attain, gen(attainment)
	recode attainment (4=1) (2=2) (3=3) (1=4) 
	label define attainment 1 "Less than primary" 2 "Primary" 3 "Secondary" 4 "Post-secondary", modify
	label val attainment attainment
	
***	round the values so they will work with spineplot
	replace attainpop = round(attainpop,1)

***	archive
	keep mekkocat attainment attainpop
	preserve 
	decode mekkocat, gen(category)
	decode attainment, gen(level_attained)
	sort mekkocat attainment
	keep attainpop category level_attained
	order category level_attained attainpop
	replace attainpop=attainpop/1000
	lab var attainpop "Population (millions)"
	lab var category "Country category"
	lab var level_attained "Level of schooling attained"
	wdrarchive
	restore

/*******************************************************************************
GRAPH
*******************************************************************************/	

spineplot attainment mekkocat  [fw=attainpop], ///
	legend(	///
		region(c(none) ) pos(2) symx(3) symy(3) rowgap(*.5) ///
		title("Highest level of" "education attained:", size(medsmall) just(left) bexpand color(gs0)) ///
		) ///
	xlabel(, angle(45) axis(2)) ///
	percent ///
		graphregion(c(white) lw(thick) lc(white) margin(b-5 l-1 r-3 t-2) ) ///
		plotregion(m(b-1 r-1 l-1 t-1)) ///
		xscale(noline axis(1)) ///
		xscale(noline axis(2)) ///
		yscale(noline axis(1)) ///
		yscale(noline axis(2)) ///
		barall( blcolor(white) blw(thick)) ///
		bar1(color("${wdrscheme1}") fi(100)) ///
		bar2(color("${wdrscheme5}") fi(100)) ///
		bar3(color("${wdrscheme3}") fi(100)) ///
		bar4(color("${wdrscheme2}") fi(100)) ///
		xtitle("Percent of world", axis(1)) ///
		xtitle("", axis(2)) ///
		ytitle("Percent of region", axis(2)) ///
		xsize(6.5) ysize(4) ///
		name(stock, replace)
	
graph display stock, scale(1.1)

/*******************************************************************************
EXPORT
*******************************************************************************/	

wdrexport , ///
	title(Most of the world’s population with less than a primary education is in South Asia, but rates are similar in Sub-Saharan Africa) ///	
	subtitle(Stock of educational attainment (ages 15-64), by region (2010)) ///
	source(WDR 2018 team, using data from Lee and Lee (2016).) ///
	chapter(2) figure(2)
	
/*******************************************************************************
DISPLAY SUMMARY STATS FOR VERIFICATION
*******************************************************************************/	

***	table of summary stats 
	gen attainpop_mil = attainpop/1000
	label var mekkocat "Region"
	label var attainpop_mil "Population (millions), by attainment"
	label var attainment "Population (millions), by attainment"
	format attainpop_mil %5.0fc
	
	table  mekkocat attainment, c(sum attainpop_mil) f(%9.0f) col row cell(14)

exit

