/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Figure 2.3
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load data
	use "${data}/UIS 2016 school completion", clear

***	clone variables to collapse
	ds comp_*
	local comp_vars `r(varlist)'
	foreach var of local comp_vars {
		foreach ptile in 25 50 75 {
			clonevar `var'_p`ptile' = `var'
			local clist `clist' (p`ptile') `var'_p`ptile'
			local `var'_p`ptile'_lbl : var label `var'_p`ptile'
			}
			}
	tempfile bycountry
	save `bycountry'

***	collapse for the entire world
	use			`bycountry', clear
	collapse 	`clist'
	gen 		class=3 // CHANGE TO 4 IF USING DUMMIES (FCS AND HIPC BELOW)
	gen 		label="World"
	tempfile 	chartdata
	save		`chartdata'

***	collapse by income group
	use 		`bycountry', clear
	replace		incomegroup=5 if group_OED==1
	lab def		incomegroup 4 "High income (non-OECD)" 5 "High income (OECD)", modify
	collapse	`clist', by(incomegroup)
	decode		incomegroup, gen(label)
	drop		incomegroup
	gen			class=1
	app using	`chartdata'
	save		`chartdata', replace
	
***	collapse by region
	use 		`bycountry', clear
	sum			comp_sec if region==4, de
	noi di 		"These MENA countries won't be included, because they're not developing:"
	noi list	country if region==4 & incomegroup==4
	drop		if incomegroup==4
	sum			comp_sec if region==4, de
	collapse	`clist', by(region)
	decode		region, gen(label)
	drop		region
	gen			class=2
	app using	`chartdata'
	save		`chartdata', replace
	
***	apply var labels
	foreach var of local comp_vars {
		foreach ptile in 25 50 75 {
			label var `var'_p`ptile' "``var'_p`ptile'_lbl'"
			}
			}
			
***	archive
	preserve
	drop class
	reshape long comp_sec comp_pri, i(label) j(percentile) str
	destring percentile, i(_p) replace
	rename label category
	lab var category "Country category
	lab var percentile "Percentile"
	lab var comp_sec "Secondary completion rate"
	lab var comp_pri "Primary completion rate"
	wdrarchive
	restore
	
***	gen rank var, sorted by class and completion rate
		gsort class -comp_sec_p50
		gen rank=_n+class-1
			
***	reshape
	reshape long 	comp_sec_p comp_pri_p, i(label rank) j(ptile) 
	recode			ptile (25 75=0 "quartile") (50=1 "median"), gen(plot_type)
	reshape long	comp_, i(label rank ptile) j(level) str
	replace			level="Primary" 		if level=="pri_p"
	replace			level="Lower secondary" if level=="sec_p"
	encode 			level, gen(aux_level)
	replace			rank=(rank*3)-3
	replace			rank=rank-1 if aux_level==2
	rename			comp_ rate

***	marker labels
	gen 			mlabel=label if ptile==25 & aux_level==2, after(label)
	*bysort label: egen mlabel_x = max(rate)
	egen mlabel_x=max(rate)
	bysort label: egen mlabel_y = mean(rank)
	
***	save
	save `chartdata', replace
	tempfile working
	save `working'

/*******************************************************************************
STRUCTURE DATA
*******************************************************************************/

***	set up marker labels to serve as a key
	use `working', clear
	gen legend_label="" // to be replaced by elements of the legend label
	
***	generate labels indicating each quartile
	sum rank
	expand=2 if rank==`r(max)', gen(legend_label_pos) // this first expansion is for the percentile markers
	recode legend_label_pos (0=.) (1=0) // position 0 --> labels will go below the markers to which they correspond
	levelsof ptile, local(ptiles)
	foreach p of local ptiles { // apply percentile labels
		replace legend_label	="`p'th" 		if ptile==`p' & legend_label_pos ==0
		}
	sum rank
	replace rank=`r(max)'+1 if legend_label_pos !=. // move the labels down one rank from the markers being labeled
	
***	generate "Percentile" label to go underneath
	sum rank
	expand=2 if rank==`r(max)' & ptile==50 & legend_label_pos ==0, gen(legend_title)
	replace legend_title=. if rank<`r(max)'-1
	
	replace legend_label="Percentile" if legend_title==1
	sum rank
	replace rank=`r(max)'+1.75 if legend_title ==1
	replace rank=rank+1.5 if legend_label_pos !=.
		
***	save
	save `working', replace	
		
/*******************************************************************************
GRAPH WITH LEGEND
*******************************************************************************/

***	loop over these categories
	use `working', clear
	rename label unit
	levelsof unit, local(units)
	recode	aux_level (2=1) (1=2), gen(catnum) // adjust the catgory numbers here to change the colors of the boxplots
	levelsof catnum, local(categories)
	save `working', replace

***	generate grid lines
	sum mlabel_y
	gen  	xgrid_y=`r(max)'+1
	local	xgrid_ymin = `r(min)'-2
	keep xgrid_y
	duplicates drop
	expand=6
	gen xgrid_x=(_n*20)-20
	expand=2, gen(grids)
	replace xgrid_y=`xgrid_ymin' if grids==1 
	replace grids=1
	append using `working'
	save `working', replace

***	standard marker and point options
	local lopts	 m(none) lw(medthick) c(l)
	local popts	 m(O) mlw(medthick) mfc(white) 
	local mopts  m(none) mlabel(mlabel) mlabsize(vsmall) mlabpos(3) mlabc(black)
	local kopts	 mlabel(legend_label) mlabpos(0) mlabc(black) mlabsize(vsmall)

***	loop to get graphing codes
	local i=0
	foreach catnum of local categories {
		foreach unit of local units {
			local ++i
			use `working', clear
			local lines `lines' 	(scatter rank rate 			if unit=="`unit'" & plot_type==0 & catnum==`catnum'	& legend_label_pos==., `lopts'  lc("${wdrscheme`catnum'}") mlabc("${wdrscheme`catnum'}") 	)
			local points `points' 	(scatter rank rate 			if unit=="`unit'" & plot_type==1 & catnum==`catnum'	& legend_label_pos==., `popts' mlc("${wdrscheme`catnum'}") 							)
			local mlabs	`mlabs'     (scatter mlabel_y mlabel_x	if unit=="`unit'" & plot_type==0					& legend_label_pos==., `mopts')
				}
			}
	local j=`i'/2
		
***	loop to get gridlines
	forvalues x=0(20)100 {
		local xgrids `xgrids' (scatter xgrid_y xgrid_x if xgrid_x==`x', m(none) c(l) lp(shortdash) lc(gs0) lw(thin))
		}
		*local xgrids `xgrids' (scatter xgrid_y xgrid_x if xgrid_x==100, m(none) c(l) lp(solid) lc(gs0) lw(thin))

***	graph
	use `working', clear
	twoway ////
		`xgrids' ///
		(scatter rank rate if ptile==25 & legend_title==0							, lc(black) c(l) m(none)) ///	leader line for ptile==25
		(scatter rank rate if ptile==50 & legend_title==0							, lc(black) c(l) m(none)) ///	leader line for ptile==50
		(scatter rank rate if ptile==75	& legend_title==0							, lc(black) c(l) m(none)) ///	leader line for ptile==75
		(scatter rank rate if			  legend_title==0	& legend_label_pos==0	, `kopts' m(O) mc(white) msize(medlarge) ) ///	marker labels for percentiles
		(scatter rank rate if			  legend_title==1	& legend_label_pos==0	, `kopts' m(none) ) ///	marker labels for percentiles
		///
		`lines' `points' `mlabs' ///
			, ///
		legend(order(`j' `i') label(`j' "Primary school") label(`i' "Lower-secondary school")  c(1) rowgap(0) symx(3) symy(3) region(c(none) m(t-2)) size(vsmall)) /// 
		graphregion(c(white)lc(white)lw(thick) m(r+35 b-6 l-5 t-2 )) ///
		xscale(r(0 100) noline alt ) ///
		yscale(noline reverse) ///
		ylabels("") ///
		xlabels(0(20)100, labgap(-2) notick labsize(vsmall)) /// tlc(gs15) grid glc(gs12) glp(shortdash) glw(thin) notick
		title("") ///
		ytitle("") ///
		plotregion(c(none)) /// m(t-2 b-2)
		xtitle("{bf:Completion rate}",  color(black) size(vsmall)  just(center) ) ///
		ysize(5) xsize(3.75) ///
		scale(1.5) ///
	name(x, replace)
			
/*******************************************************************************
EXPORT
*******************************************************************************/
	
wdrexport , ///
	title(National income is correlated with the gap between primary and lower secondary completion rates) ///
	subtitle(Distribution of completion rates across countries, by country group and level of schooling) ///
	source(WDR 2018 team, using data from UIS (2016).) ///
	note(Geographic regions exclude high-income countries. The data presented are the latest available, by country, for the period 2010–16. Completion rates include students whose age exceeds the official age group for a particular education level, and so the rate may exceed 100 percent.) ///
	chapter(2) figure(3)

exit	
