/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
ternary plot of Lee and Lee 2016
*******************************************************************************/

*** WDR settings
	include wdrsettings

/*******************************************************************************
PREP STOCK DATA
*******************************************************************************/

***	load and trim Lee and Lee 2016
	use "${data}/Lee and Lee 2016 education stock", clear
	drop if region==.
	local tiers lu lp ls lh 
	tempfile leelee
	save `leelee'
	
***	calculate stock of education for incomegroups
	use `leelee', clear
	tab incomegroup, plot
	collapse `tiers' [pw=pop], by(sex year incomegroup)
	
***	round the data
	foreach var of local tiers {
		replace `var'=round(`var',.1)
		}
	egen total=rowtotal(lu lp ls lh)
	gen diff=100-total
	replace lu=lu+diff
	foreach var of local tiers {
		replace `var'=round(`var',.1)
		}

***	rename and encode
	rename incomegroup category
	encode sex, gen(gender)
	
***	transform data to ternary friendly (combine higher education levels)
	gen lsh = ls+lh
	keep year category gender lu lp lsh
	egen miss=rowmiss(lu lp lsh)
	keep if miss==0
	drop miss

***	calculate percentages
	egen tots = rowtotal(lu lp lsh)
	foreach var in lu lp lsh {
		replace `var' =(`var'/tots)*100
		}

***	label vars
	label var lu "Less than primary"
	label var lp "Primary" 
	label var lsh "Secondary or above"

***	reduce the number of observations 
	keep if mod(year,10)==0
	drop if year<1890
	keep if gender==3
	drop gender
	
***	save working file
	tempfile working
	save `working'

***	archive
	preserve
	decode category, gen(country_category)
	sort category year
	keep country_category year lu lp lsh
	order country_category year lu lp lsh
	lab var country_category "Country category"
	foreach var in lu lp lsh {
		local lbl : var label `var'
		local lbl ="`lbl' (percent)"
		lab var `var' "`lbl'"
		}
	wdrarchive
	restore
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	load data, and trim to 1890-current and total (no genders)
	use `working', clear


***	generate marker labels
	tostring year, gen(mlabel)

***	further thin the marker labels per white cover comments
	recode year (1890 1920 1950 1980 2010 = 1), gen(dum_mlabel)
	replace mlabel="" if dum_mlabel !=1
	replace mlabel="" if category==2 & year>1890 & year <1950 
	replace mlabel="" if category <3 & year==1920
	drop if category <3 & year >1890 & year<1950
	drop if category==3 & year >1890 & year<1920
	
***	generate mlabel position var
	gen mlabv = 3
	replace mlabv =9  if category==2 & year >=1980
	replace mlabv =9  if category==2 & year ==1870
	replace mlabv =4  if category==3 & year ==1870
	replace mlabv =9  if category==1 & year >=1980
	replace mlabv =9  if category==2 & year ==1910
	replace mlabv =6  if category==4 & year >=1960
	replace mlabv =12 if category==3 & year >=1990
	replace mlabv =11 if category==3 & year ==2000
	replace mlabv =9  if category==2 & year ==1890
	replace mlabv =12 if category==4 & year >=2000
	replace mlabv =9  if category==3 & year <=1940 & year >=1920
	
*** set options for each category, by setting the same option equal to the number of categories
	levelsof category, local(cats)
	foreach cat of local cats {
	local connect 	`connect' l
		local marker	`marker' o
		local mlw		`mlw'	thick
		local width		`width' thick
		local lp		`lp' solid
		local mlabel	`mlabel' mlabel
		local mlabsize	`mlabsize' small
		local mlabg		`mlabg' *.05
		}

***	graph
	sort category year
	triplot lu lp lsh  , c(`connect') lw(`width') m(`marker') separate(category)  ///
		max(100) ///
		frame(lc(gs0) lw(medthin)) ///
		grid(lc(gs0) lp(shortdash) lw(vthin) mlabsize(medlarge)) ///) ///
		mlabel	(`mlabel') ///
		mlabsize(`mlabsize') ///
		mlabg	(`mlabg') ///
		mlabp	(`mlabp') ///
		mlabv	(mlabv) ///
		mlabc	("$wdrscheme1" "$wdrscheme2" "$wdrscheme3" "$wdrscheme4" ) ///
		lc		("$wdrscheme1" "$wdrscheme2" "$wdrscheme3" "$wdrscheme4" ) ///
		mc		("$wdrscheme1" "$wdrscheme2" "$wdrscheme3" "$wdrscheme4" ) ///
		lp		(`lp') ///
		mlw		(`mlw') ///
		graphregion(c(white)lw(thick)lc(white)margin( r+16.5)) ///
		plotregion(margin(r-8)) ///
		text(mlabsize(medium)) ///
		legend(size(medium) region(c(none) m(r-24)  ) symx(5) symy(5) rowgap(*.1) pos(2)) ///
		ysize(3) xsize(4) ///
		name(stock_mf, replace)

/*******************************************************************************
EXPORT
*******************************************************************************/
		
	wdrexport , ///
		title(Low-income countries are bypassing the historical pattern among high-income countries in which most people were educated at the primary level before coverage extended to secondary) ///
		subtitle(Evolution in the stock of educational attainment (ages 15–64), by present-day income group (1890–2010)) ///
		source(WDR 2018 team, using data from Lee and Lee (2016).) ///
		chapter(2) figure(4)

		exit
	
