
/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load and recode PASEC data
	use "${data}/PASEC 2014 by proficiency", clear
	sum year
	keep if year==`r(max)'
	rename lo_pasec_mat_6_l* math*
	rename lo_pasec_rea_6_l* read*
	keep math* read* country year
	reshape long math read, i(country) j(level)
	rename (math read) pct=
	reshape long pct, i(country level) j(subject) str
	tempfile PASEC
	save `PASEC', replace

***	generate variable to recode
	gen performance=level, after(level)
	sort _all

***	recode PASEC
	recode performance (0/2=1)	(3=2) 	(4=3) 		if subject=="read" // PASEC reading
	recode performance (0/1=1)	(2=2) 	(3/4=3) 	if subject=="math" // PASEC mathematics

***	collapse by user-defined performance level
	collapse (sum) pct , by(subject performance country)
	sort subject country performance

***	reshape wide
	reshape wide pct, i(country subject) j(performance)
	replace pct1 = -pct1
	tempfile tests
	save `tests'
	
***	collapse, weighting by population, and merge averages
	gen year=2014
	merge m:1 country year using "${data}/WDI 2017 school age populations", keep(3 1) nogen keepusing(SP_SEC_LTOT_IN)
	collapse pct* [pw=SP_SEC_LTOT_IN], by(subject)
	gen country="All PASEC countries"
	append using `tests'
	save `tests', replace

***	generate sort variable
	bysort subject (pct1): gen sort = _n
	compress _all
	save `tests', replace

***	archive data
	preserve
	keep subject country pct1 pct2 pct3 
	order subject country pct1 pct2 pct3 
	replace pct1 =-pct1
	gsort subject -pct1
	replace subject="Mathematics" if subject=="math"
	replace subject="Reading" if subject=="read"
	lab var subject "Subject"
	lab var country "Country"
	lab var pct1 "Not competent (percent)"
	lab var pct2 "Low competency (percent)"
	lab var pct3 "High competency (percent)"
	wdrarchive
	restore

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set locals for legends
	local lgnd label(1 "Not competent") label(2 "Low competency") label(3 "High competency")
	local read_sub "a. Reading"
	local math_sub "b. Mathematics"	

***	set locals for options
	local lmargin 25
	local bmargin -11
	
*** set locals
	levelsof subject, local(subjects)

***	plot bar chart
	foreach subject of local subjects {
		graph hbar pct1 pct2 pct3 if subject=="`subject'", ///
			over(country, axis(noline) sort(sort)  ) ///
			stack nofill   ///
			outergap(-50) ///
			title({bf:``subject'_sub'}, bexpand just(left) size(medium) color(black) ) ///
		legend(`lgnd' r(1) region(c(none)m(t+8))  symx(2) symy(2) size(small)) ///
		graphregion(c(none)lw(thick)lc(none)m(l+`lmargin')) ///
			bar(1, col(${wdrscheme2})) ///
			bar(2, col(${wdrscheme5})) ///
			bar(3, col(${wdrscheme1})) ///
		text(-100 `bmargin' "100") 	 yline(-100 , lw(thin) lp(shortdash) lc(gs4)) ///
		text(-50  `bmargin'  "50") 	 yline(-50	, lw(thin) lp(shortdash) lc(gs4)) ///
		text(0 	  `bmargin'   "0") 	 yline(0	, lw(thin) lp(shortdash) lc(gs4)) ///
		text(50   `bmargin'  "50") 	 yline(50	, lw(thin) lp(shortdash) lc(gs4))  ///
		text(100  `bmargin' "100") 	 yline(100	, lw(thin) lp(shortdash) lc(gs4)) ///
				ylabels("", grid glc(gs4) glp(shortdash) glw(thin) notick) ///
			yline (0	, lw(medthin) lc(gs4)) ///
			ytitle("Percentage of sixth-graders", size(medsmall) margin(b-10) color(black)) ///
		yscale(r(-100 100) noline ) ///
			name(`subject', replace)
		local test_combo `test_combo' 	`subject'
		}
	
*** combine panels
	grc1leg read math, graphregion(c(white)lw(thick)lc(none)m(l-5 r+1 b-1 t+1))  imargin(0 0 0 0) name(comp_tests, replace)
	graph draw comp_tests, xsize(6.5) ysize(3) scale(1.5)
	graph drop math read
	
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Most grade 6 students in West and Central Africa are not sufficiently competent in reading or mathematics) ///
	subtitle(Competency levels from PASEC (2014), by subject in participating countries) ///
	source(WDR 2018 team, using data from Programme d’Analyse des Systèmes Educatifs de la Confemen (PASEC 2015) and World Bank’s World Development Indicators (World Bank 2016c).) ///
	note(For the PASEC reading exam, not competent refers to levels 0–2 in the original coding, low competency to level 3, and high competency to level 4. For the PASEC mathematics exam, not competent refers to levels 0–1 in the original coding, low competency to level 2, and high competency to level 3.) ///
	chapter(3) figure(1)
	
exit

