/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Distribution of education spending on staff compensation, by income group
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load data
	use "${data}/UIS 2017 staff compensation", clear
	
***	drop low-population countries
	rename SPPOPTOTL ctry_pop
	lab var ctry_pop "Population of the country"
	drop if ctry_pop<500000
	
***	keep only vars we need
	rename (SPPRMTOTLIN SPSECTOTLIN) (pri_pop sec_pop)
	rename (pri_FNS sec_FNS) (pri_exp sec_exp)
	
/*******************************************************************************
GRAPH
*******************************************************************************/
	
***	set output options
	local source "WDR 2018 team with data from EdStats (2017)."
	local title "Staff compensation consumes the vast majority of resources available for public education"
	local subtitle "Staff compensation as percentage of total expenditure in public education, by country and income level"
			
***	construct population weights
	gen tot_pop =pri_pop+sec_pop
	foreach level in pri sec {
		gen		`level'_wgt =`level'_pop/tot_pop 
		egen 	aux_`level'_wgt = mean(`level'_wgt)
		replace	`level'_wgt = aux_`level'_wgt if `level'_wgt==.
		drop 	aux_`level'_wgt
		}
	
***	construct overall spending percentage using weights, when possible
	gen 	tot_exp = pri_wgt*pri_exp + sec_wgt*sec_exp
	replace tot_exp = pri_exp if tot_exp==.
	replace tot_exp = sec_exp if tot_exp==.
	drop if tot_exp==.
	
***	decode category	
	decode incomegroup, gen(category)
	
***	label variables
	lab var category "Income group"
	lab var tot_pop "school-age population"
	lab var pri_wgt "primary-age population"
	lab var sec_wgt "secondary-age pouplation"
	lab var tot_exp "weighted average (primary and secondary) of expenditures to staff compensation"
	lab var country "Country"
		
***	drop extraneous variables
	keep country incomegroup category tot_exp
	compress _all
	
***	archive data
	preserve
	gsort incomegroup -tot_exp
	drop incomegroup
	order category country, first
	wdrarchive
	restore

***	generate sort variable
	gsort incomegroup -tot_exp
	gen sort=_n+2*(incomegroup-1)
	lab var sort "x-axis sorting variable"
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	set options & macros

	local text1 ""
	local topts placement(w) size(small)
	forvalues y=0(20)100 {
		local text1 `text1' text(`y' -5 "`y'", `topts') 
		local grids `grids' yline(`y', lc(gs12) lw(thin))
		}
	local ytit1 Percent of spending
	sum sort
	local xmax =`r(max)'+2
	local xmin =`r(min)'-2
	
***	pull group titles	
	preserve
	bysort incomegroup: egen sortx=mean(sort)
	keep incomegroup category sortx
	duplicates drop
	splitstring category
	local addedtext
	levelsof incomegroup, local(igs)
	sort incomegroup
	foreach ig of local igs {
		sum sortx if incomegroup==`ig'
		local addedtext `addedtext' text(-1 `r(mean)' "`=category_line1[`ig']'" "`=category_line2[`ig']'", size(medsmall) color(black) placement(s))
		}
	restore
	
***	graph by category
	foreach level in tot {
		twoway (bar `level'_exp sort, color("$wdrscheme5") fi(100) barwidth(.65) ), /// 		
			ytitle("Percent", margin(r-2) size(medsmall) color(black)) ///
			ylabel(0(20)100, glc(gs2) glw(thin) notick angle(h)) ///
			yscale(range(0 100) noline) ///
			graphregion(c(white)lc(white)lw(thick)margin(t-2 b+3)) ///
			`addedtext' ///
			xlabel(none) xscale(noline) xtitle("") ///
			xsize(6.5) ysize(2.25) ///
			scale(1.3) ///
			name(`level'_exp_bar, replace)
			}

*** resize
	graph draw tot_exp_bar, xsize(6.5) ysize(2.25) 
			
/*******************************************************************************
EXPORT
*******************************************************************************/
	
wdrexport , ///	
	title(Staff compensation consumes the vast majority of resources available for public education) ///
	subtitle(Staff compensation as percentage of total expenditure on public education, by country and income group) ///
	source(WDR 2018 team, using data from UNESCO Institute for Statistics (UIS 2017)) ///
	note(Figure includes all countries with populations of over 500,000 for which spending data are available at the primary or secondary levels.) ///
	chapter(3) figure(11)
