/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
manipulate data
*******************************************************************************/

***	loop through both datasets
	use "${data}/TERCE 2013 socioeconomic inequalities", clear
		
***	keep richest and poorest quintiles
	keep if status ==1 | status ==5

***	collapse levels 2-3 into "low competency"; rename new levels 1 and 3
	egen pct2 =rowtotal(lvl2 lvl3)
	rename lvl1 pct1
	rename lvl4 pct3
	drop lvl?
	
***	label variables
	order pct1 pct2 pct3, last
	lab var pct1 "Not competent"
	lab var pct2 "Low competency"
	lab var pct3 "High competency"
	
***	generate sort var
	preserve
	keep if status==1
	sort pct1
	gen sort = _n
	tempfile sorted
	keep subject country sort
	save `sorted'
	restore
	merge m:1 subject country using `sorted', nogen
	
***	reorder
	order subject country status sort pct1 pct2 pct3
	sort subject status pct1

***	archive
	preserve
	drop sort
	wdrarchive
	restore
	
***	make "not competent" negative
	replace pct1=-pct1
	
***	save
	tempfile testgraphfile
	save `testgraphfile'
	
/*******************************************************************************
graph
*******************************************************************************/

***	set locals for legends
	local lgnd label(1 "Not competent") label(2 "Low competency") label(3 "High competency")
	local LIT_sub "a. Reading"
	local NUM_sub "b. Mathematics"	

***	set options
	local gopts lw(thin) lp(shortdash) lc(gs4)
	local mb -6
	
***	set graph options

	local subjects Reading Mathematics
	levelsof status,  	local(statuses)
	tokenize `c(alpha)'
	local i=0

***	graph
	foreach subject of local subjects {
		local ++i
		graph hbar pct1 pct2 pct3 if subject=="`subject'", ///
			over(status, axis(noline) gap(20) relabel(2 "Rich" 1 "Poor") label(labsize(small)) )  ///
			over(country,  sort(sort) des  gap(80) label(labgap(0))) ///
			stack nofill   ///
			outergap(-50) ///
			title({bf:``i''. `subject'}, bexpand just(left) size(medium) color(black) ) ///
		legend(`lgnd' r(1) region(c(none)m(t+8))  symx(2) symy(2) size(small)) ///
		graphregion(c(none)lw(thick)lc(none)m(l+14 r-6 )) ///
		plotregion(margin(l-3)) ///
			bar(1, col(${wdrscheme2})) ///
			bar(2, col(${wdrscheme5})) ///
			bar(3, col(${wdrscheme6})) ///
	text(-100  `mb'  "100") 	 yline(-100	, `gopts') ///
	text(-50  `mb'  "50") 	 yline(-50	, `gopts') ///
	text(0 	  `mb'   "0") 	 yline(0	, lw(thin) lp(solid) lc(gs4) ) ///
	text(50   `mb'  "50") 	 yline(50	, `gopts' )  ///
	text(100  `mb' "100") 	 yline(100	, `gopts' ) ///
			ylabels("", grid glc(gs4) glp(shortdash) glw(thin) notick) ///
			yscale(noline) ///
			ytitle("Percentage of students", size(medsmall) margin(b-10) color(black)) ///
		yscale(r(-100 100) noline ) ///
			name(`subject', replace)
		local test_combo `test_combo' 	`subject'
	}

***	combine graphs
	grc1leg `test_combo', graphregion(c(white)lw(thick)lc(none)m(l-2 r-1 b-1 t+1))  imargin(-20 0 0 0) name(comp_tests, replace)

***	resize graph
	sum sort
	local height=.1*`r(N)'
	graph draw comp_tests, xsize(6.5) ysize(`height') scale(`scale`round'') name(graph`round', replace)

***	drop graphs
	graph drop comp_tests
	
/*******************************************************************************
export
*******************************************************************************/
	
	wdrexport , ///
		title(Learning outcomes are substantially lower for poor children in Latin America) ///
		subtitle(Competency levels for TERCE (2013) grade 6, by subject for students in poorest and richest socioeconomic quintiles, in participating countries) ///
		source(WDR 2018 team, using data from Third Regional Comparative and Explanatory Study (TERCE), 2013 (UNESCO 2013).) ///
		note(Socioeconomic quintiles are defined nationally. Not competent refers to level 1 in the original coding, low competency refers to levels 2-3, and high competency refers to level 4.) ///
		chapter(3) figure(3)

