/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	trim the data
	use "${data}/PISA 2015", clear
	sum 	year
	keep 	if year==`r(max)'
	split 	pisa_country			, p(-) g(ave)
	gen		average=1 				if ave2 =="35" // flag only the 35-country OECD average
	drop 							if ave1=="OECD average" &	average !=1 // drop all other OECD averages
	replace	average=0 				if average==.
	gen 	nonbank=1 				if country==""
	replace	nonbank=0 				if nonbank==.
	replace country=ave1 			if country==""
	replace country="China (B-S-J-G)"  		if pisa_country=="B-S-J-G (China)"
	drop if country=="CABA (Argentina)"
	drop 	pisa_country ave?
	reshape wide score, i(country year ptile subject) j(stat) str
	rename score* *
	rename _all, lower
	tempfile working
	save `working'

*** merge with OECD dummy
	merge m:1 code using ${data}/class, nogen keep(1 3) keepusing(group_OED)
	replace group_OED=0 if group_OED==.
	sort country subject ptile
	save `working', replace

***	generate dummy for countries below 25th percentile of OECD
	use `working', clear
	forvalues x=25(25)75 {
		gen				tempoecd = score if average==1 & ptile==`x'
		bysort subject: egen oecd_`x'=min(tempoecd)
		drop tempoecd
		}
	save `working', replace
	
***	indicate OECD countries we want to include in the graph
	use `working', clear
	gen		select_oecd=0
	replace select_oecd=1 if code=="CHL"
	replace select_oecd=1 if code=="POL"
	replace select_oecd=1 if code=="MEX"
	replace select_oecd=1 if code=="FIN"
	replace select_oecd=1 if code=="KOR"
	replace select_oecd=1 if code=="TUR"
	gen 	select=0
	replace select=1 if select_oecd==1 
	replace select=1 if group_OED==0
	replace select=1 if average==1
	save `working', replace

***	fix long name
	use `working', clear
	replace country="Dominican Rep." if country=="Dominican Republic"
	save `working', replace

***	distinguish between 25/75, 50, and 10/90
	use `working', clear
	gen plot_type =0
	replace plot_type=1 if ptile==50
	replace plot_type=2 if ptile==10
	replace plot_type=2 if ptile==90
	save `working', replace

***	drop extranneous countries
	use `working', clear
	drop if select==0
	drop if plot_type==2 // do not drop if you want to include 10/90
	save `working', replace

***	generate rank variables using medians for each subject
	use `working', clear
	keep if ptile==50
	drop if average==1
	bysort subject: egen rank =rank(score), field
	keep subject country rank
	merge 1:m subject country using `working', nogen
	save `working', replace

***	generate rank variables for the OECD average, by subject
	use `working', clear
	levelsof subject, local(subjects)
	foreach subject of local subjects {
		sum rank if subject=="`subject'"
		replace rank =`r(max)'+2 if average==1 & subject=="`subject'"
		}
	save `working', replace	

***	label variables
	lab var country "Country"
	lab var subject "Subject"
	lab var ptile "Percentile"
	lab var score "PISA 2015 score"
	
***	archive
	foreach subject in Reading Mathematics {
		preserve
		keep country subject ptile score
		replace subject=proper(subject)
		keep if subject=="`subject'"
		wdrarchive, title(`subject')
		restore
		}

/*******************************************************************************
SET UP GRAPHING FIELDS
*******************************************************************************/
	
***	trim to just the data to graph
	use `working', clear
	keep if select==1
	keep if plot_type ==0 | plot_type ==1
	save `working', replace
	
***	set up marker labels
	use `working', clear
	sum ptile
	gen mlabel=country if ptile==`r(min)'
	save `working', replace
	
***	generate corner points for interquartile range
	sort rank
	expand=3 if average==1 & plot_type==0, gen(interquartile) // duplicate the 25th and 75th percentiles for the OECD average
	bysort rank interquartile subject (ptile): replace interquartile=_n if interquartile!=0 // replace indicator for half the expanded observations (replaces 1 with 2)
	sum rank
	local boxmargin=.5
	replace rank=`r(min)'-`boxmargin' if interquartile==1 | interquartile==4
	replace rank=`r(max)'+`boxmargin' if interquartile==3 | interquartile==2
	save `working', replace

***	set up marker labels to serve as a key
		use `working', clear
		local leaderline_offset=.5
		local leaderline_length=.9
	*** identify the bottom (rightmost) plot
		gen rightmost=0
		sum rank if interquartile==0
		replace rightmost=1 if rank==`r(max)'
	***	keep only the rightmost & trim data
		keep if rightmost==1
		keep ptile rank score average select_oecd select plot_type subject
		gen legend_label_pos=0
	***	generate labels
		gen legend_label=""
		levelsof ptile, local(ptiles)
		foreach p of local ptiles {
			replace legend_label	="`p'th" 		if ptile==`p' & legend_label_pos ==0 
			}	
***	expand once more to add the label of the labels (i.e. the legend title)
		expand=2 if ptile==50, gen(legend_title)
		replace legend_label="Percentile" if legend_title==1
	***	expand to create points for leader lines
		expand=2 if legend_title!=1, gen(leader_lines)
	
	***	adjust ranks to determine the x-coordinate values for leader lines
		replace rank=rank+`leaderline_offset'+`leaderline_length' 	if leader_lines==1
		replace rank=rank+`leaderline_offset' 						if leader_lines==0
	***	adjust 25th, 50th, 75th percentile labels
		replace legend_label_pos=6   if legend_title==0 
		replace legend_label_pos=6  if legend_title==1
	*** append and save
		append using `working'
		save `working', replace
	

***	set up grid lines
		use `working', clear
	***	summarize vars to get the appropriate xy values for the gridlines
		qui sum rank if legend_title==.
		local gridymin `r(min)' // this sets the top edge of the interquartile box
		local gridymax `r(max)' // this sets the bottom edge of the interquartile box
		sum score
		local gridxmin=100*round((`r(min)' / 100))
			local gridxmax=100*round((`r(max)' / 100))
	***	set up blank file
		keep subject
		duplicates drop
		gen score=.
		tempfile gridblank
		save `gridblank'
		tempfile gridbuild
		save `gridbuild'
	***	loop to establish x's
		forvalues x=`gridxmin'(50)`gridxmax' {
			use `gridblank', clear
			replace	score=`x'	
			append using `gridbuild'
			save `gridbuild', replace
			}
		drop if score==.
		save `gridbuild', replace
	***	double observations to establish y's
		use `gridbuild'
		gen 	plot_type=2
		expand=2, gen(expand)
		gen		rank=`gridymin' if expand==0
		replace	rank=`gridymax' if expand==1
		drop expand
		save `gridbuild', replace
	***	append to working dataset
		use `working', clear		
		append using `gridbuild'
		save `working', replace
		
	*** fix interquartile indicators
		use `working', clear
		replace interquartile=0 if leader_lines!=.
		replace interquartile=0 if legend_title!=. 
		save `working', replace
		
/*******************************************************************************
SET LOCALS FOR GRAPHING
*******************************************************************************/

***	choose titles
	local mathematics_ttl "b. Mathematics"
	local reading_ttl "a. Reading"
	local science_ttl "c. Science"
	

***	loop over these categories
	use `working', clear
	levelsof subject, local(subjects)
	levelsof country, local(countries)

***	loop to get graphing codes
	foreach country of local countries {
		use `working', clear
		sum group_OED if country=="`country'"
		local catnum=`r(mean)'+1 // trickery
		local lines `lines' 	(scatter rank score if country=="`country'" & plot_type==0 & average==0, c(l) mlabel(mlabel) mlabsize(vsmall) m(none) lw(medium) lc("${wdrscheme`catnum'}") mlabc("${wdrscheme`catnum'}") mlabpos(9) )
		local points `points' 	(scatter rank score if country=="`country'" & plot_type==1 & average==0,  m(o) mlw(medium) mlc("${wdrscheme`catnum'}") mfc(white) )
		}

***	hard code average line
	local averageline ///
	(scatter rank score if plot_type==0 & average==1 & interquartile==0 & legend_label_pos==., c(l) mlabel(mlabel) mlabsize(vsmall) m(none) lw(medium) lc("${wdrscheme2}") mlabc("${wdrscheme2}") mlabpos(9) ) /// line for OECD average
	(scatter rank score if plot_type==1 & average==1 & interquartile==0 & legend_label_pos==.,  m(o) mlw(medium) mlc("${wdrscheme2}") mfc(white)  ) // median for OECD average

	
***	loop for gridlines
	use `working', clear
	keep if plot_type==2
	levelsof score, local(scores)
	foreach score of local scores {
		local gridlines `gridlines' (scatter rank score if plot_type==2 & score==`score', m(none) c(l) lc(gs11) lp(shortdash) lw(vvthin) )
		}

/*******************************************************************************
GRAPH
*******************************************************************************/

***	choose what to chart where	
	local rightsubjects mathematics
	local leftsubjects reading
	
***	graph with legend
	foreach subject of local leftsubjects  {
		use `working', clear
			sort average subject  ptile interquartile rank 
		keep if subject=="`subject'"
		twoway ////
		(area rank score if average==1 & interquartile !=0,  fcolor(gs15) fi(100) lcolor(gs15)) ///
 	(scatter rank score if ptile==25 & legend_title==0, lc(gs4) c(l) m(none) lw(thin)) ///	leader line for ptile==25
 	(scatter rank score if ptile==50 & legend_title==0, lc(gs4) c(l) m(none) lw(thin)) ///	leader line for ptile==50
 	(scatter rank score if ptile==75 & legend_title==0, lc(gs4) c(l) m(none) lw(thin)) ///	leader line for ptile==75
	`gridlines' `lines' `points' ///
(scatter rank score if leader_lines==0 & legend_title==1 & legend_label_pos!=., m(none) mlabel(legend_label) mlabvpos(legend_label_pos) mlabel(legend_label) mlabsize(vsmall) mlabc(black) mlabgap(*5)) /// add marker labels for legend (bottom of chart)
	(scatter rank score if leader_lines==1 & legend_title==0 & legend_label_pos!=., m(none) mlabel(legend_label) mlabvpos(legend_label_pos) mlabel(legend_label) mlabsize(vsmall) mlabc(black) mlabgap(0)) /// add marker labels for legend (bottom of chart)
			`averageline' ///
				, ///
			legend(  order(16 17 1)  label(1 "OECD interquartile range") label(16 "non-OECD") label(17 "OECD") r(1) symx(3) symy(3) region(c(none)m(t+3 l-15)) size(vsmall)) ///
			xscale(r(300 600) noline alt ) /// 
			yscale(noline reverse) ///
			ylabels("",) ///
			xlabels(300(100)600,  tlc(gs15) nogrid glc(gs15) glw(thin) notick labsize(vsmall)) ///
			title("") ///
			ytitle("") ///
			plotregion(c(none)m(t-2 b-2)) ///
			graphregion(c(white)lw(thick)lc(white)) ///
			xtitle("{bf:``subject'_ttl'}", bexpand color(black) size(vsmall) margin(l-8) just(left) ) ///
			name(`subject'_with, replace)
		}

***	graph without legend
	foreach subject of local rightsubjects {
		use `working', clear
			sort average subject  ptile interquartile rank 
			gen blankstring=""
		keep if subject=="`subject'"
		twoway ////			
			(area rank score if average==1 & interquartile !=0,  fcolor(gs15) fi(100) lcolor(gs15)) ///
			`gridlines' `lines' `points' `averageline' ///
			(scatter rank score if average==1 & legend_label_pos!=., m(none) msize(medium) mc(white) mlabel(blankstring) mlabvpos(legend_label_pos) mlabsize(vsmall) mlabc(black)) /// add marker labels for legend (bottom of chart)
			, ///
			legend(off) ///
			xscale(r(300 600) noline alt ) ///
			yscale(noline reverse) ///
			ylabels("",) ///
			xlabels(300(100)600,  nogrid notick labsize(vsmall)) ///
			title("") ///
			ytitle("") ///
			plotregion(c(none)m(t-2 b-2)) ///
			graphregion(c(none)lw(thick)lc(white)) ///
			xtitle("{bf:``subject'_ttl'}", bexpand color(black) size(vsmall) margin(l-8) just(left) ) ///
			name(`subject'_without, replace)
		}

*** combine graphs
	grc1leg  reading_with mathematics_without ,  imargin(0 3 0 0)	graphregion(c(white)lw(thick)lc(white)  m(l+12 r-10 t-2 b-4) ) iscale(*1.5) xcommon name(box, replace)
	graph display box, xsize(6.5) ysize(7.5)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport, ///
	title(Learning outcomes vary greatly across countries and economiesin several countries, the 75th percentile on PISA performs below the 25th percentile of the OECD average) ///
	subtitle(Performance of 25th, 50th, and 75th percentiles in 2015 PISA assessment in participating non-OECD economies and selected OECD economies) ///
	source(WDR 2018 team, using data from Program for International Student Assessment (PISA) collected in 2015 (OECD 2016a).) ///
	note(PISA 2015 defines baseline levels of proficiency at a score of 407 for reading and 420 for mathematics. China (B-S-J-G) = China (Beijing-Shanghai-Jiangsu-Guangdong).) ///
	chapter(3) figure(4)

	exit	
