/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load and clean
	use "${data}/PIAAC and STEP various years", clear
    keep country low_1564 // low_1524
	egen missing=rownonmiss(low*)
	drop if missing==0
	drop missing
	merge 1:1 country using "${data}/class", keepusing(incomegroup) keep(3) nogen

***	rescale
	ds low_*
	foreach var in `r(varlist)' {
		replace `var' =`var'*100
		}

***	recode incomegroup
	gen ig=incomegroup
	recode ig (1/3=1) (4=2)
	tab incomegroup ig
	lab def ig 1 "Middle income" 2 "High income", replace
	lab val ig ig
	drop incomegroup

***	generate median for high income countries and drop everything below
	sum low_1564 if ig==2, de
	local hic_median =`r(p50)'
	replace country="Median HIC" if low_1564 < `hic_median' & ig==2
	replace low_1564= `hic_median' if low_1564 < `hic_median' & ig==2
	
***	gen vars
	gen below=-low_1564
	gen above=100+below
	compress _all
	duplicates drop
	
***	archive data
	preserve
	decode ig, gen(incomegroup)
	keep incomegroup country below above
	order incomegroup country below above
	replace below=-below
	gsort -incomegroup -below 
	lab var incomegroup "Income group"
	lab var country "Country"
	lab var below "Low reading proficiency (percent)"
	lab var above "Medium-high reading proficiency (percent)"
	wdrarchive
	restore
		
/*******************************************************************************
GRAPH
*******************************************************************************/

***	gridlines
	forvalues y=-75(25)100 {
		local texty = abs(`y')
		local grid `grid' yline(`y', lc(gs8) lp(shortdash)) text(`y' -4 "`texty'")
		}
		
*** graph
	graph hbar below above, ///
		over(country, sort(below) axis(noline)) ///
			over(ig, label(nolabels) gap(*2)) ///
			nofill ///
		stack ///
		`grid' ///
		yline(0, lc(gs0) lp(solid)) ///
		bar(1, color("${wdrscheme7}")) ///
		bar(2, color("${wdrscheme5}")) ///
		ylabels("") ///
		legend(region(c(none)margin(t-1)) ///
			title("Reading proficiency:", size(medsmall) just(right) bexpand color(gs0) pos(9) margin(r+1)) ///
			label(1 "Low") ///
			label(2 "Medium–High") ///
			symx(4) symy(2) ///
			pos(6) r(1) ///
			colgap(*.35) ///
			keygap(*.5) ///
			) ///
		text(-92.5 101 "{bf:Middle income}", placement(nw) just(right)) ///
		text(-92.5 56 "{bf:High income}", placement(nw) just(right)) ///
		graphregion(c(white)lc(white)lw(thick)margin(l-6 b-5 r+.5)) ///
		plotregion(margin(b-2 t-2)) ///
		ytitle("Percent", margin(t+5)) ///
		yscale(noline) ///
		xsize(3) ysize(4)
	
/*******************************************************************************
EXPORT
*******************************************************************************/
		  
	wdrexport , ///
		title(High-income countries (HICs) tend to have greater rates of literacy proficiency than middle-income countries) ///
		subtitle(Percentage of working-age population relative to minimal level of foundational literacy (2011–14)) ///
		source(WDR 2018 team, using data from Programme for the International Assessment of Adult Competencies (PIAAC) collected between 2011 and 2014 (OECD 2016b, 2016c) and STEP Skills Measurement Program, 2011-14 (microdata.worldbank.org/index.php/catalog/step/about).) ///
		note(Data are the latest available by country. PIAAC is representative at the national level for adults, ages 16–65. STEP is representative for urban populations, ages 15–64. Low proficiency is defined as levels 1 and below on the assessments and indicates limited understanding of basic texts. Medium to high proficiency is defined as levels 2 and above and indicates the ability to integrate, evaluate, and interpret information from a variety of text materials.) ///
		chapter(3) figure(5)
		

exit

