/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Figure 3.5 Population with low literacy mekko plot
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA 
*******************************************************************************/

***	decide what estimators/models to keep
	local keepestimators 	schl
	local keepmodels		 m08
	local keepthese
	local agegroups 1524 
	
	***	loop for keepvars
		foreach est of local keepestimators {
			foreach mod of local keepmodels {
				local keepthese `keepthese' popl*`est'*`mod'
				}
				}
		noi di "`keepthese'"
	
	*** generate age group labels	
		foreach agegroup of local agegroups {
			local `agegroup'_lo = substr("`agegroup'",1,2)
			local `agegroup'_hi = substr("`agegroup'",3,2)
			}
	
***	use estimate data
	use "${data}/Larson and Valerio 2017", clear

***	keep only the models we want
	keep country code region incomegroup pop_1524_mil pop_1564_mil `keepthese'
	rename popl* pop*

***	create category for mekko plot
	***	generate string vars
		foreach var in region incomegroup {
			decode `var', gen(str_`var')
			order str_`var', after(`var')
			}
		gen 	str_mekko 	=str_region
		replace str_mekko 	=str_incomegroup 	if incomegroup==4
	***	generate ordering var
		gen		axis_mekko 	=region
		sum 	region
		replace axis_mekko 	=`r(max)'+1 		if incomegroup==4 
	*** put them together 
		egen	mekkocat= axis(axis_mekko), label(str_mekko)
	*** order
		order *mekko*, after(code)
		sort mekkocat
	***	drop countries that aren't classified
		noi di _newline(2) as text "No category, being dropped:"
		list country code if mekkocat==.
		drop if mekkocat==.
		
***	rename vars for convenience
	foreach est of local keepestimators { // this will crash if we keep both estimators
		rename *_low_`est'* **
		}


***	rename to identify estimates as those of low literacy
	foreach agegroup of local agegroups {
		foreach model of local keepmodels {
			rename pop_`agegroup'_`model' pop_lo_`agegroup'_`model' 
			}
			}

***	calculate the population that does not have low literacy
	foreach agegroup of local agegroups {
		foreach model of local keepmodels {
			gen pop_hi_`agegroup'_`model' = pop_`agegroup'_mil - pop_lo_`agegroup'_`model'
			}
			}
			
***	generate percentage vars
	foreach agegroup of local agegroups {
		foreach model of local keepmodels {
			foreach stat in hi lo {
				gen pct_`stat'_`agegroup'_`model'  =  pop_`stat'_`agegroup'_`model' / pop_`agegroup'_mil 
				}
				}		
				}

***	label variables
	foreach agegroup of local agegroups {
		foreach model of local keepmodels {
			lab var pct_lo_`agegroup'_`model' "Population (%) with low literacy, ages `agegroup'"
			lab var pct_hi_`agegroup'_`model' "Population (%) with high literacy, ages `agegroup'"
			lab var pop_hi_`agegroup'_`model' "Population (millions) with high literacy, ages `agegroup'"
			}
			}
			
***	save as temp for collapsing to region-wide mekkoplot
	tempfile working
	save `working'
	
/*******************************************************************************
PREP DATA 
*******************************************************************************/			

***	load
	use `working', clear
	
***	pull all labels
	qui ds
	foreach var in `r(varlist)' {
		local `var'_lbl : var label `var'
		}

***	collapse by mekko category
	collapse (sum) pop* , by(mekkocat)
		
***	reapply labels
	ds
	foreach var in `r(varlist)' {
		lab var `var' "``var'_lbl'"
		}
			
***	generate percentage vars
	foreach agegroup of local agegroups {
		foreach model of local keepmodels {
			foreach stat in hi lo {
				gen pct_`stat'_`agegroup'_`model'  =  pop_`stat'_`agegroup'_`model' / pop_`agegroup'_mil 
				}
				}		
				}
				
***	rename vars
	foreach model of local keepmodels {
		rename *`model' `model'*
		}
	
***	drop unnecessary vars
	drop *mil
	
***	reshape
	reshape long m06pct m08pct m06pop m08pop, i(mekkocat) j(cat) str
	
***	split age group for ids
	split cat, p(_)
	***	skills category
		gen 	aux_cat2 =1 if cat2=="lo"
		replace aux_cat2 =2 if cat2=="hi"
		replace cat2="Medium-High" if cat2=="hi"
		replace cat2="Low" if cat2=="lo"
		egen skills = axis(aux_cat2), label(cat2)
	***	age group
		rename cat3 agegroup
	***	drop remainder
		drop cat*
	
***	rescale
	ds *pop
	foreach var in `r(varlist)' {
		replace `var'=round(1000000*`var',1)
		}
	ds *pct
	foreach var in `r(varlist)' {
		replace `var'=round(`var',.001)
		}

***	drop extranneous data
	drop if skills==.
	keep mekkocat m08pop skills
	rename m08pop pop

***	archive data
	preserve
	decode mekkocat, gen(category)
	decode skills, gen(proficiency)
	lab var category "Country category"
	lab var proficiency "Reading proficiency"
	lab var pop "Population"
	keep pop category proficiency
	wdrarchive
	restore

/*******************************************************************************
PLOT STANDARD MEKKO w/ JUST RELEVANT AGE GROUPS
*******************************************************************************/

	
*** set options
	local titopts size(medsmall) just(left) bexpand color(gs0)
	
	spineplot skills mekkocat  [fw=pop] , ///
		legend(	///
		keygap(*.25) ///
		region(c(none) ) pos(2) symx(3) symy(3) rowgap(*.5) ///
		title("Reading proficiency:", size(medsmall) just(left) bexpand color(gs0)) ///
		) ///
		xlabel(, angle(45) axis(2)) ///
	percent /// text(`model'popmil, mlabc(white)) ///
	graphregion(c(white) lw(thick) lc(white) margin(b-5 l-3  t-2)  ) ///
		plotregion(m(b-1 r-1 l-1 t-1)) ///
		xscale(noline axis(1)) ///
		xscale(noline axis(2)) ///
		yscale(noline axis(1)) ///
		yscale(noline axis(2)) ///
		barall( blcolor(white) blw(thick)) ///
		bar1(color("${wdrscheme8}") fi(100)) ///
		bar2(color("${wdrscheme2}") fi(100)) ///
		xtitle("Percent of world", axis(1)) ///
		xtitle("", axis(2)) ///
		ytitle("Percent of region", axis(2)) ///
		xsize(6.5) ysize(4) ///
		scale(1.1) ///
		name(spineplot, replace)
	

/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Reading proficiency is low in many parts of the developing world) ///
		subtitle(EEstimated population ages 15-24, by country group and level of reading proficiency) ///	
		source(WDR 2018 team, using data from Larson and Valerio (2017).) ///
		note(Model predicts proportion of working-age adults scoring at level 1 or below on the PIAAC-STEP scale based on 41 countries, then projects to world population. PIAAC = Programme for the International Assessment of Adult Competencies; STEP = STEP Skills Measurement Programme.) ///
		chapter(3) figure(6) 

