/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	bin width setting
	local binwidth 13

***	load data
	use "${data}/PISA 2015 socialindex", clear

***	rename and recode vars
	clonevar code=cnt 
	replace code="TWN" if code=="TAP"
	replace code="ROM" if code=="ROU"
	replace code="CHN" if code=="QCH"
	preserve
	bysort cnt: gen countervar=1 if _n==1
	tab cnt, sum(countervar)	
	restore
	
***	only keep units that are countries, and count them 
	
	***	merge with classification table to determine what's a country and what's not
		merge m:1 code using "${data}/class", keepusing(country) 
		
	***	report units that are not countries
		preserve
		bysort cnt: gen countervar=1 if _n==1
		tab cnt if _merge !=3, sum(countervar)
		tab cnt if _merge ==3, sum(countervar)
		drop if _merge !=3
		collapse countervar, by(cnt)
		sum countervar 
		local total_unique_countries `r(sum)'
		restore
	
	***	drop what doesn't belong
		drop if qescs==99
		drop if _merge !=3
		drop _merge
		
***	clone weight variable
	clonevar wgt=w_fstuwt
	lab var math "Mathematics"
	lab var wgt "Weight"

***	set survey
	svyset [pw=wgt]
	
***	set locals that will keep through the whole do file
	local subjects read math scie 

***	save as temp working file
	tempfile working
	save `working'

***	calculate stats for overall distribution in all subjects

	foreach subject of local subjects {
		***	survey mean, display results, save them to matrices and then locals
			svy : mean `subject'
			estat sd
			mat 	sd 			= r(sd)
			mat 	mean 		= r(mean)
			local 	`subject'sd		=sd[1,1]
			local 	`subject'mean	=mean[1,1]
		***	apply mean and standard deviation measures to additional locals
			local `subject'_mean		=``subject'mean'
			local `subject'_plus_1 		=``subject'mean'+``subject'sd'
			local `subject'_plus_2		=``subject'mean'+``subject'sd'+``subject'sd'
			local `subject'_max			=``subject'mean'+(2.5*``subject'sd')
			local `subject'_minus_1 	=``subject'mean'-``subject'sd'
			local `subject'_minus_2		=``subject'mean'-``subject'sd'-``subject'sd'
			local `subject'_min			=``subject'mean'-(2.5*``subject'sd')
			local `subject'_sd			=``subject'sd'
			}
	*/

***	find modes of density estimates
	
	***	set up local to find maximum density from among all of the modes calculated
		local max_density =0
	
	***	loop to find modes, etc
		foreach subject of local subjects {
			foreach q in 1 5 {
				*** calculate mode
					sort qescs `subject'
					kdensity 	`subject' [aw=wgt] if qescs==`q', gen(`subject'x`q' `subject'd`q') nograph n(150) bw(12.5) 
					tempvar 	aux_`subject'd`q' 
					qui gen 	`aux_`subject'd`q'' = round((`subject'd`q'*1000000000),1)
					qui sum 	`aux_`subject'd`q'' 
					qui sum 	`subject'x`q' if `r(max)' == `aux_`subject'd`q'' 
					local 		`subject'_mode_`q' = `r(mean)'
				***	calculate density at which mode is observed	
					qui sum 	`subject'd`q' if round(``subject'_mode_`q'',4) == round(`subject'x`q',4)
					local 		`subject'_dens_`q' = `r(mean)'
				***	calculate mean
					 qui sum		`subject' [aw=wgt] if qescs==`q'
					 local		`subject'_mean_`q' = `r(mean)'
				***	report results on screen
					noi di as text _newline "`subject' score, SEC quintile `q'"
					noi di as text "mode:    ``subject'_mode_`q''"
					noi di as text "mean: 	 ``subject'_mean_`q''"
					noi di as text "density: ``subject'_dens_`q''"
				
				*** pull maximum density from among all the densities
					if `max_density' < 	``subject'_dens_`q'' {
						local max_density = ``subject'_dens_`q''
				}
				}
				}
	
	***	save these estimates for use in the data archive
		tempfile data_archive_estimates
		save `data_archive_estimates'
		
	***	find y-value for our span linesgiven maximum calculate density
		noi di 					`max_density'
		local 	span_y = 1.05*	`max_density'
		

***	use locals defined above to generate additional observations for our tic 
* 	marks, mean spanning lines, and other twoway graph elements not covered 
* 	by kdensity
	
	***	set up blank file and file for appending
		clear
		set obs 1
		gen subject=""
		gen element_name=""
		gen element_label=""
		gen element_type=.
		gen element_x=.
		gen element_y=.
		gen element_q=.
		tempfile blank_elements
		save `blank_elements'
		tempfile graph_elements
		save `graph_elements'
	
	***	element 1: spanning bars
		foreach subject of local subjects {
			use `blank_elements', clear
			replace subject			="`subject'"
			replace element_name	="span" 
			replace element_y		=`span_y'	
			replace	element_type	=1
			local i=0
			foreach q in 1 5 {
				local ++i
				replace element_q		=`q' 					if _n==_N // this is for the tic mark along the x axis
				replace element_x		=``subject'_mean_`q'' 	if _n==_N // this assigns the value calculated above
				expand 					=2 						if _n==_N & `i' < 2
				}
		***	append to the elements build file
			append using `graph_elements'
			save `graph_elements', replace
			}
	
	***	element 2: tic marks
		
		***	set locals 
			local elements mean plus_1 plus_2 minus_1 minus_2 
			local elements_cnt : list sizeof elements
			noi di `elements_cnt'
	
		***	loop over subjects
			foreach subject of local subjects {
				use `blank_elements', clear
				replace subject			="`subject'" // identify the subject
				replace element_type	=2 // categorical var to identify 
				
			*** loop over elements within those subjects
				local i=0
				foreach element of local elements {
					local ++i
					replace element_name	="`element'" 			if _n==_N // name the element 
					replace element_label	="`element'"			if _n==_N
					replace element_y		=0 						if _n==_N // this is for the tic mark along the x axis
					replace element_x		=``subject'_`element'' 	if _n==_N // this assigns the value calculated above
					expand 					=2 						if _n==_N & `i' < `elements_cnt'
					}
		
			***	fix element label
				replace element_label = subinstr(element_label,"mean","Mean",.)
				replace element_label = subinstr(element_label,"_","",.)
				replace element_label = subinstr(element_label,"minus","-",.)
				replace element_label = subinstr(element_label,"plus","+",.)
				replace element_label = subinstr(element_label,"2","2 SD",.)
				replace element_label = subinstr(element_label,"1","1 SD",.)
	
		
			***	append to the elements build file
				append using `graph_elements'
				save `graph_elements', replace
					}
		*/
	*** element 3: marker showing approximate number of years the gap represents
		foreach subject of local subjects {
						
			***	identify the type of element & subject
				use `blank_elements', clear
				replace subject			="`subject'" // identify the subject
				replace element_type	=3 // categorical var to identify 
				replace element_name	="mean span"
				
			***	calculate stats
				local midpoint = (``subject'_mean_1' + ``subject'_mean_5') / 2
				local years = (``subject'_mean_5' - ``subject'_mean_1')/41
				local years = round(`years',.01)
								
			***	display stats
				noi di as text _newline "subject:      `subject'"
				noi di as text "midpoint:     `midpoint'"
				noi di as text "approx years: `years'"
			
			***	populate dataset with calculatd stats
				replace element_y		=`span_y'	
				replace element_x		=`midpoint'
				replace element_label	="~`years' years"
					
			***	append to the elements build file
				append using `graph_elements'
				save `graph_elements', replace
			}
	

	*** element 4: mode spans
		
		foreach subject of local subjects {
			
			***	identify the type of element & subject
				use `blank_elements', clear
		
			***	plot a bar spanning the modal averages
				local i=0
				local span_y=0
				foreach q in 1 5 {
					local ++i // the counting variable tells the loop when to stop expanding observations
					if `span_y' < ``subject'_dens_`q''	{  // the maximum density between the two curves is where our spanning bar y value will be
						local span_y = ``subject'_dens_`q''	
						}
					replace element_q		=`q' 					if _n==_N // this is for the tic mark along the x axis
					replace element_x		=``subject'_mode_`q'' 	if _n==_N // this assigns the value calculated above
					replace element_name	="span"					if _n==_N 
					expand 					=2 						if _n==_N & `i' < 2
					}
				replace element_y		=`span_y'			
				
			***	add markers to the density curves to explicitly show the modal average
				local i=0
				foreach q in 1 5 {
					expand 					=2 						if _n==_N & `i' < 2
					local ++i // the counting variable tells the loop when to stop expanding observations
					replace element_q		=`q' 					if _n==_N // this is for the tic mark along the x axis
					replace element_x		=``subject'_mode_`q'' 	if _n==_N // this assigns the value calculated above
					replace element_y		=``subject'_dens_`q'' 	if _n==_N 
					replace element_name	="mode"					if _n==_N 
					}
			
			***	add leader lines for the ends of the span to the mode markers
				
				foreach q in 1 5 {
					local i=0
					foreach terminal in top bottom {
						expand 					=2 						if _n==_N & `i' < 2
						local ++i // the counting variable tells the loop when to stop expanding observations
						replace element_q		=`q'					if _n==_N
						replace element_x		=``subject'_mode_`q'' 	if _n==_N // this assigns the value calculated above
						replace element_y		=``subject'_dens_`q'' 	if _n==_N & "`terminal'"=="bottom"
						replace element_y		=`span_y' 				if _n==_N & "`terminal'"=="top"
						replace element_name	="leader"				if _n==_N
						}
						}
												
			***	calculate midpoint stats
				local midpoint 	= (``subject'_mode_1' + ``subject'_mode_5') / 2
				local points	= ``subject'_mode_5' - ``subject'_mode_1'
				local years 	= `points' / (100/3)
				local years : di %3.1f `years' 
			
			***	expand again and apply the calculated stats to the midpoint label
				expand 	=2									if _n==_N
				replace element_x		=`midpoint'			if _n==_N
				replace element_name	="mid"				if _n==_N
				replace element_label	="~`years' years"	if _n==_N
				replace element_q		=.					if _n==_N
				replace element_y		=`span_y'			if _n==_N 
				local `subject'_mid_x = `midpoint'
				local `subject'_mid_y = 1.025*`span_y'
				local `subject'_mid_yrs = `years'
				local points =round(`points',1)
				local `subject'_mid_pts = `points'				
				
			***	these values are common for all aspects of this subject
				replace subject			="`subject'" // identify the subject
				replace element_type	=4 // categorical var to identify 
				
			***	display stats
				noi di as text _newline "mode subject:      `subject'"
				noi di as text "mode midpoint:     `midpoint'"
				noi di as text "mode approx years: `years'"
				
		***	append to the elements build file
			append using `graph_elements'
			save `graph_elements', replace
		}
	

***	append additional graph elements to main data file
	use `graph_elements', clear
	drop if element_type==.
	append using `working'
	lab var subject "Subject"
	save `working', replace

***	archive data
	
	***	set locals for panel titles
		local read_panel_ttl Reading
		local math_panel_ttl Mathematics
		local scie_panel_ttl Science
		
	***	prep data for panels
		use `data_archive_estimates', clear
		keep readd1 readx1 readd5 readx5 mathd1 mathx1 mathd5 mathx5 scied1 sciex1 scied5 sciex5
		foreach subject in read math scie {
			lab var `subject'd1 "``subject'_panel_ttl' score density (bottom socioeconomic quintile)"
			lab var `subject'd5 "``subject'_panel_ttl' score density (top socioeconomic quintile)"
			lab var `subject'x1 "``subject'_panel_ttl' score (bottom socioeconomic quintile)"
			lab var `subject'x5 "``subject'_panel_ttl' score (top socioeconomic quintile)"
			}
		save `data_archive_estimates', replace
		
	*** panels a-c: reading, math, science
		local panelno=0
		foreach subject in read math scie {
			use `data_archive_estimates', clear
			ds `subject'*
			keep `r(varlist)'
			egen missing=rownonmiss(`r(varlist)')
			drop if missing==0
			drop missing
			wdrarchive, title(``subject'_panel_ttl')
			}
	
	***	panel d will be just the calculated modes
		use `working', clear
		keep if element_name=="mode"
		keep subject element_?
		lab def element_q 1 "Low" 5 "High"
		lab val element_q element_q
		decode element_q, gen(status)
		lab var status "Socioeconomic status"
		replace subject="Mathematics" if subject=="math"
		replace subject="Science" if subject=="scie"
		replace subject="Reading" if subject=="read"
		rename element_x mode
		lab var mode "Modal average"
		keep subject status mode
		order subject status mode
		sort subject status
		wdrarchive, title(Modal averages)

/*******************************************************************************
GRAPH
*******************************************************************************/	

***	load data
	use `working', clear
	
***	set locals to control graph features, like added text and axis options, etc
	local thickness medthick
	local yttl_read "Density of scores"
	local y_math noline
	local y_scie noline
	local y_read line
	local gopts graphregion(c(white)lc(white)lw(thick)margin(l-3 r-3 t-5 b-5)) ///
				ylabels(, nolab nogrid notick angle(h)) ///
				plotregion(margin(b-2.2)) 
	local lopts lw(`thickness') n(150) bw(12.5) 
	local textsize small
	local topts bexpand just(left) color(black) size(`textsize')
	local textyloc  -.0001
	local readtitmargin l+1
	local mathtitmargin l+3
	local scietitmargin l+3
	tokenize `c(alpha)'

***	loop to get code for tic marks, by subject
	foreach subject of local subjects { 
		levelsof element_name if subject=="`subject'"  & element_type==2, local(names)
			foreach name of local names {
				local `subject'_tic ``subject'_tic' (scatter element_y element_x  if element_name=="`name'" & element_type==2 & subject=="`subject'", m(o) mc(black) msize(small) mlabel(element_label) mlabpos(6) mlabsize(vsmall) mlabc(black) mlabgap(*.25))
			}
		}

***	loop to get code for span lines, by subject
	foreach subject of local subjects { 
		local `subject'_span ``subject'_span' (scatter element_y element_x  if element_type==1 & subject=="`subject'", m(none) c(l) lc(black) lw(thick))
		}
		
***	loop for element 3: equivalent years difference
	foreach subject of local subjects {
		local `subject'_yrs ``subject'_yrs' (scatter element_y element_x if element_type==3  & subject=="`subject'", m(none) mlabel(element_label) mlabc(black) mlabpos(12) mlabsize(vsmall))
		}
	
***	loop for element 4: mode bars
	foreach subject of local subjects {
		local `subject'_spans ``subject'_modes' (scatter element_y element_x  if element_type==4 & subject=="`subject'" & element_name=="span"					, m(none) c(l) lc(gs6) lw(medthin))
		}
	foreach subject of local subjects {
		local `subject'_modes ``subject'_modes' (scatter element_y element_x  if element_type==4 & subject=="`subject'" & element_name=="mode" & element_q==1	, m(O) msize(medium) mlw(medthick) mlc("${wdrscheme3}") mfc(white))
		local `subject'_modes ``subject'_modes' (scatter element_y element_x  if element_type==4 & subject=="`subject'" & element_name=="mode" & element_q==5	, m(O) msize(medium) mlw(medthick) mlc("${wdrscheme4}") mfc(white))
		}
	foreach subject of local subjects {
		local `subject'_leads ``subject'_leads' (scatter element_y element_x  if element_type==4 & subject=="`subject'" & element_name=="leader"					, m(none) c(l) lc(gs6) lp(shortdash) lw(thin))
		}
		
		
***	loop across subjects to generate density graphs
	local count=0
	foreach subject of local subjects {
		local ++count
		local ttl : var label `subject'
		local ttl = subinstr("`ttl'"," Score","",.)
		local lttl =lower("`ttl'")
		
		twoway /// 
			``subject'_leads' /// 	
			``subject'_spans' /// 	
			(kdensity `subject' if qescs==1 & `subject'>``subject'_min' & `subject'<``subject'_max' [aw=wgt] , `lopts' lc("${wdrscheme3}"))	 ///
			(kdensity `subject' if qescs==5 & `subject'>``subject'_min' & `subject'<``subject'_max'	[aw=wgt] , `lopts' lc("${wdrscheme4}")) 	///
				``subject'_modes' ///
				, ///
			`gopts' ///
			text(``subject'_mid_y' ``subject'_mid_x' "``subject'_mid_pts' points =" "~``subject'_mid_yrs' years", size(`textsize') color(black) placement(north)) ///
			title("{bf:``count''. `ttl'}" , `topts' margin(``subject'titmargin' b+2)) ///
			ytitle("`yttl_`subject''", size(`textsize')) ///
				yscale(`y_`subject'') ///
			xtitle("Score", size(`textsize') margin(t+1)) /// 			
			xlabel(, labsize(`textsize')) ///
				legend(region(c(none)margin(t-1)) label(3 "Low socioeconomic status") label(4 "High socioeconomic status") /// 
				order(3 4) symx(3) symy(2) size(`textsize') ) /// 
			name(den_`count', replace)
			}
	
	grc1leg den_1 den_2 den_3, r(1) graphregion(c(white)lc(white)lw(thick)margin(b-4 l-2 r-1)) iscale(1) ycommon xcommon name(socioecon_density, replace)
	graph display socioecon_density, xsize(6.5) ysize(2.5) scale(1.7)
	graph drop den_1 den_2 den_3
	
/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Family socioeconomic status significantly affects students’ average PISA scores) ///
		subtitle(Distribution of gap in mean scores on PISA 2015 across 69 countries (pooled) for students from the bottom and top quintiles of socioeconomic status, by subject) ///
		source(WDR 2018 team, using data from Program for International Student Assessment (PISA) collected in 2015 (OECD 2016a).) ///
		note(The density of differences in mean scores across 69 countries are given for students from the top and bottom socioeconomic quintiles. A year of education is assumed to equal roughly 33 points on the PISA exam in this analysis, and the gap is calculated as the difference between modal averages of the top and bottom quintiles for each subject.) ///
		chapter(3) figure(7)
	
exit
