/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

*** WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	set up blank file
	clear
	gen sheet=""
	tempfile working
	save `working' 

***	import flow data and manipulate
	use "${data}/UIS 2010 and 2015 and WIDE 2017 flows", clear
	replace level = proper(level)
	egen schooling= axis(aux_level), label(level)
	bysort schooling: egen cattotal =sum(students)
	expand=2 if action=="leave", gen(expanded)
	replace action="left" if expanded==1 
	replace students=100-cattotal if expanded==1
	drop if students==0
	gen base=0
	tostring students, gen(label1)
	replace label1 =label +" "+action
	gen label2=lower(level)
	replace students=(100-cattotal)+students if action=="leave"
	replace students = -students if action !="complete"

***	generate leave labels
	local labgap 3
	preserve
	keep if action=="leave"
	sort schooling
	levelsof schooling, local(schools)
	foreach school of local schools {
		local leavetext `leavetext' text(`=students[`school']-`labgap'' `=schooling[`school']' `"`=label1[`school']' before"' `"completing"' , placement(s))
		}
	restore
	
***	generate complete labels
	preserve
	keep if action=="complete"
	sort schooling
	levelsof schooling, local(schools)
	foreach school of local schools {
		local completetext `completetext' text(`=students[`school']+`labgap'' `=schooling[`school']' `"`=label1[`school']'"' `"{bf:`=label2[`school']'}"', placement(n))
		}
	restore

***	set identifier and save
	gen panel=1
	tempfile working
	save `working', replace

***	archive flow data
	keep level action students
	lab var level "Level of schooling"
	lab var action "Action students take"
	lab var students "Students (percent) who took specified action"
	wdrarchive, title(Of 100 students who enter primary around the world)
	
***	import regional data
	use "${data}/UIS 2010 and 2015 and WIDE 2017 regional", clear
	drop if region=="World"
	replace leave=-leave
	gsort -complete
	gen aux_region=_n+3.5
	gen panel=2
	preserve
	splitstring region
	keep if panel==2
	replace region_line1=trim(region_line1)
	replace region_line2=trim(region_line2)
	
***	set labels
	gen uid=_n
	levelsof uid, local(regions)
	foreach uid of local regions {
		sort aux_region
		local regionlbl `regionlbl' text(-80 `=aux_region[`uid']' "`=region_line1[`uid']'" "`=region_line2[`uid']'", placement(s))
		}
	restore

*** archive regional data
	preserve
	keep region complete leave
	lab var complete "Students who completed given level"
	lab var leave "Students who left before completing given level" 
	lab var region "Region"
	wdrarchive, title(But given disparate rates attaiment varies greatly)
	restore
	
*** combine with flow data and save
	append using `working'
	save `working', replace

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set grid lines
	sum aux_region if panel==2
	local gridxmin=`r(min)'-.4
	local gridxmax=`r(max)'+.4
	clear
	set obs 7
	gen gridy=25*(_n-4)
	expand=2, gen(gridx)
	replace gridx= `gridxmin' if gridx==0
	replace gridx= `gridxmax' if gridx==1
	gen panel=3
	tempfile grids
	append using `working'	
	save `working', replace

***	loop for gridlines commands
	levelsof gridy, local(grids)
	local legendplus : word count `grids' 
	foreach grid of local grids {
		local gridlines `gridlines' (scatter gridy gridx if gridy==`grid', c(l) m(none) lc(gs2) lw(thin) lp(shortdash))
		}

***	set immediate graph options
	local bardwidth .6
	sum aux_level if panel==1
	local level_x =`r(min)'-.6
	sum aux_region if panel==2
	local region_x=`r(min)'-.6
	forvalues l=1/3 {
		local legend`l' = `l'+`legendplus'
		}

***	graph
	twoway ///
		`gridlines' ///
		(bar students schooling if panel==1 & action=="complete", color("$wdrscheme6") fi(100) barwidth(`bardwidth')) ///
		(bar students schooling if panel==1 & action=="leave"	, color("$wdrscheme2") fi(100) barwidth(`bardwidth')) ///
		(bar students schooling if panel==1 & action=="left"	, color("$wdrscheme3") fi(100) barwidth(`bardwidth')) ///
		(bar complete aux_region if panel==2					, color("$wdrscheme6") fi(100) barwidth(`bardwidth')) ///
		(bar leave aux_region if panel==2						, color("$wdrscheme2") fi(100) barwidth(`bardwidth')) ///
			, ///
			`leavetext' `completetext' ///
			`regionlbl' ///
			legend(region(c(none)margin(t+5)) order(`legend1' `legend2' `legend3') label(`legend1' "Completed") label(`legend2' "Left before completing") label(`legend3' "Left previously") symx(3) symy(3) r(1)) ///
			xlabel(none) xscale(noline) xtitle(" ") ///
			ylabel(-75 "75" -50 "50" -25 "25" 0 25 50 75, nogrid notick angle(h) ) yscale(range(-75 75) alt noline) ytitle(" ") ///
			ytitle("Percent", margin(b-15)) ///
			plotregion(margin(t+10)) ///
			yline(0, lc(black) lw(medium) ) ///
			graphregion(c(white)lc(white)lw(thick)margin(t+3 l+1 r-2 b-4)) ///
		text(130 `level_x' "{bf:a. Of 100 students who enter primary}" "{bf:    around the world...}", placement(e) color(black) just(left)) ///
		text(130 `region_x' "{bf:b. But given disparate attrition rates across regions, upper secondary attainment}" "{bf:    varies greatly...}", placement(e) color(black) just(left)) ///
		xsize(6.5) ysize(3) ///
		name(fullgraph, replace)

/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(Young people follow different paths in their education) ///
		subtitle(Completion and leave rates (percent), by cohort and region) ///
		source(WDR 2018 team , using UIS (2017) (data.uis.unesco.org), WIDE (2017) (www.education-inequalities.org), and UNESCO (2015).) ///
		note(Estimates are for circa 2010.) ///
		chapter(5) figure(6)
		
exit


