/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	import data
	use "${data}/STEP 2013-2015 high skills good jobs", clear
	
***	rescale
	replace beta=100*beta
	replace se	=100*se
	
***	calculate confidence intervals
	local tscore 1.96 // assuming high N
	gen conlo	= (beta - (`tscore' * se))
	gen conhi = (beta + (`tscore' * se))
	
***	gen dummy for signficance
	gen 	sig=0
	replace sig=1 if conlo>0

***	generate sort order
	sort beta
	gen sort=_n
	
***	fix country names
	replace country=trim(country)
	
***	reshape 
	reshape long con, i(country beta se sig) j(ends) str

***	generate marker label
	gen mlabel1=country if ends=="hi"
	gen aux_mlabel2=round(beta,.1) if ends=="hi"

	gen mlabel2=string(aux_mlabel2)+"%"

***	save temp
	tempfile working
	save `working', replace
	
***	archive data
	keep country beta se
	duplicates drop
	lab var country "Country"
	lab var beta "coefficient estimate for likelihood of entering white-collar jobs" 
	lab var se "standard error for likelihood of entering white-collar jobs"
	wdrarchive
	
/*******************************************************************************
GRAPH
*******************************************************************************/
	
	use `working', clear
	
***	set graph options
	local sigcolor1 "$wdrscheme3"
	local sigcolor0 "$wdrscheme6"

*** loop for graph commands
	levelsof sig, local(sigs)
	foreach sig of local sigs {
		use `working', clear
		keep if sig==`sig'
		levelsof country, local(countries)
		foreach country of local countries {
			local scat `scat' (scatter sort con if country=="`country'" & sig==`sig', c(l) lw(medthick) m(none) lc("`sigcolor`sig''") mlabel(mlabel1) mlabsize(medsmall) mlabc("`sigcolor`sig''"))
			local scat `scat' (scatter sort beta if country=="`country'" & sig==`sig' & ends=="hi", c(l) mlw(medthick) m(O) mlc("`sigcolor`sig''") lw(medthick) lc("`sigcolor`sig''") mfc(white) )
			}
			}
	
***	graph
	use `working', clear
	twoway `scat' , ///
		graphregion(c(white)lc(white)lw(thick)margin(r+4)) ///
		legend(region(c(none)) order(6 4) ///
			title("Estimate and 95% confidence interval:", bexpand just(center) color(black) size(medsmall) pos(12) margin(t+1)) ///
			label(4 "Not significant") ///
			label(6 "Significant") ///
			rowgap(*.25) ///
			symx(7) ///
			r(1) pos(6) ///
			) ///
		ylabel(none) ///
		xlabel(, notick grid glw(thin) glc(gs2) glp(shortdash)) ///
		xscale(noline) yscale(noline) ///
		xline(0, lw(medthin) lc(gs0) lp(solid)) ///
		xtitle("Marginal probability (%)") ///
		ytitle("") ///
		xsize(2.65) ysize(3) ///
		scale(1.4) 


/*******************************************************************************
EXPORT
*******************************************************************************/
	
	wdrexport , ///
		title(Workers with higher literacy proficiency are more likely to enter white-collar jobs) ///
		subtitle(Marginal probability of entering high-skill white-collar jobs relative to blue-collar jobs when scoring at level 2 or above in literacy proficiency, for all workers in urban areas of participating countries (2011-14)) ///
		source(WDR 2018 team, using data from STEP Skills Measurement Programme (microdata.worldbank.org/index.php/catalog/step/about).) ///
		chapter(5) figure(7)
	
exit

