/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Compare PISA scores to income and spending; control for per capita income
*******************************************************************************/

*** WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/	

***	load data for panel a
	use "${data}/OECD 2016 UIS 2016 and WDI 2017 spending and learning", clear
	keep if pisa_subject=="mathematics"
	keep if pisa_ptile=="mean"
	keep country code score_hat exp_prisec_ppp_hat
	lab var country "Country"
	lab var code "Country code"
	tempfile working
	save `working'

***	archive data for panel a
	wdrarchive, title(Spending and learning outcomes)
	
***	load data for panel b and combine
	use "${data}/OECD 2016 UIS 2016 and WDI 2017 - 5 year changes", clear
	lab var country "Country"
	lab var code "Country code"
	lab var spend_change "Change in spending per secondary student, 2009-2015"
	lab var math_change "Annual change (percent) in PISA mathematics score, 2009-2015"
	
***	archive data for panel b
	wdrarchive, title(Change in spending and learning)

*** merge data
	merge 1:1 country using `working', nogen

***	label vars
	lab var spend_change "Average annual % change in per student spending, 2009-2015, secondary"
	lab var math_change "Average annual % change in PISA math scores, 2009-2015"
	rename  exp_prisec_ppp_* spend_*
	rename	score_hat math_hat

***	save
	save `working', replace
	
********************************************************************************
*	predicted by gni pc ppp
********************************************************************************

***	set titles	
	local spend_hat_ttl "Annual government spending on primary and" "secondary public education, per student (PPP)," "conditional on GNI per capita (log, PPP)"
	local math_hat_ttl "PISA 2015 mathematics score," "conditional on GNI per capita (log, PPP)"
	local spend_change_ttl "Average annual percentage change in" "spending per secondary student, 2009–2015" 
	local math_change_ttl "Average annual percentage change in" "PISA mathematics score, 2009–2015"
	local change_ttl "b. Changes in spending and learning"
	local hat_ttl "a. Spending and learning outcomes"

***	generate marker labels
	gen mlab_hat=""
	gen mlab_change=""
	foreach code in GBR LTU BGR IDN POL COL PER CZE BRA KOR SVK AUS HUN {
		replace mlab_change	=code if code=="`code'"
		}
	gen 	mlabvpos =3
	replace mlabvpos =6 if code=="CZE"
	replace mlabvpos =6 if code=="GBR"
	replace mlabvpos =6 if code=="AUS"
	replace mlabvpos =9 if code=="LTU"
	replace mlabvpos =9 if code=="BGR"
	replace mlabvpos =9 if code=="SVK"
	replace mlabvpos =9 if code=="HUN"
	
***	set range options
	***	choose ranges here
	
		local math_hat_min -100
		local math_hat_max 100
		local spend_hat_min -4000
		local spend_hat_max 6000
		local hat_x_increment 2000
		local hat_fysize 105
		local hat_fxsize 105
		local hat_topmargin 3
		
		local math_change_min -4
		local math_change_max 4
		local spend_change_min -10
		local spend_change_max 10
		local change_x_increment 5
		local change_fysize 100
		local change_fxsize 100
		local change_topmargin 0
		
	***	loop for range commands
		
			foreach panel in hat change {
				local `panel'_xlabel `spend_`panel'_min'(``panel'_x_increment')`spend_`panel'_max'
			foreach stat in math spend {
				local `stat'_`panel'_range range(``stat'_`panel'_min' ``stat'_`panel'_max')
				local `panel'_ifs ``panel'_ifs' & `stat'_`panel' >=``stat'_`panel'_min' & `stat'_`panel' <=``stat'_`panel'_max'
				
				}
				local `panel'_ifs=subinstr("``panel'_ifs'","& ","",1)
				}

***	set graph options
	local pisasource "WDR 2018 team with data from WDI (2017) and PISA (2015)."
	local lopts lc("${wdrscheme2}") lw(medthick)
	local mopts mc("${wdrscheme1}") m(O) mlabvpos(mlabvpos) mlabc("$wdrscheme1") mlabgap(*.5)
	local gopts legend(off)  ///
				aspectratio(1) ///
				ylabel(#5,nogrid angle(h)) ///
				yline(0, lc(gs8) lp(shortdash) lw(thin)) ///
				xline(0, lc(gs8) lp(shortdash) lw(thin)) 
	local topts	bexpand just(left) size(medsmall) color(black) margin(l-4)
	local sopts	bexpand just(left) size(medsmall) color(black) margin(l-4 t-1 b+1)	

***	graph commands
	foreach panel in hat change {
		local l`panel' `l`panel'' (lfit 	math_`panel' spend_`panel' if ``panel'_ifs' , `lopts') 
		local s`panel' `s`panel'' (scatter 	math_`panel' spend_`panel' if ``panel'_ifs' , `mopts' mlabel(mlab_`panel')) 
		reg math_`panel' spend_`panel'
			local r2 	: di %3.2f `e(r2)'
			local b 	: di %3.2f _b[spend_`panel']
			local cons 	: di %3.2f _b[_cons]
			local t		: di %3.2f _b[spend_`panel']/_se[spend_`panel']
			local n`panel' "y=`cons'+`b'x" "t=`t'" "R{super:2}=`r2'"
			}

***	graph all together		
	foreach panel in hat change {
		twoway `l`panel'' `s`panel'', ///
			name(`panel', replace)  ///
			`gopts' ///
			ytitle("`math_`panel'_ttl'") ///
			xtitle("`spend_`panel'_ttl'") ///
 			yscale(`math_`panel'_range') /// 	
			xscale(`spend_`panel'_range') /// 
			xlabel(``panel'_xlabel') ///
			title("{bf:``panel'_ttl'}", `topts') ///
			fxsize(``panel'_fxsize') ///
			fysize(``panel'_fysize') ///
			graphregion(c(white)lc(white)lw(thick)margin(t+``panel'_topmargin')) ///
			note("`n`panel''", ring(0) pos(5) size(small)  just(left) c(black)) 
		}
	
	graph combine hat change,  ysize(3.5) xsize(6.5) graphregion(c(white)lc(white)lw(thick)margin(l-2 t-10 b-1)) scale(1.35)
	graph drop hat change
	
***	export

	
	wdrexport , ///
		title(Simple associations between education spending and learning are weak) ///
		source(WDR 2018 team, using data from OECD (2016); UIS (2017); World Bank (2017).) ///
		note(AUS = Australia; BGR = Bulgaria; BRA = Brazil; COL = Colombia; CZE = Czech Republic; GBR =  Great Britain; HUN = Hungary; IDN = Indonesia; KOR = Republic of Korea; LTU = Lithuania; PER = Peru; POL = Poland; SVK = Slovak Republic; GNI = gross national income; PISA = Programme for International Student Assessment; PPP = purchasing power parity.) ///
		chapter(9) figure(2)

