/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
SET UP DATA FILE
*******************************************************************************/

***	trim the data
	use "${data}/PISA 2015", clear
	sum 	year
	keep 	if year==`r(max)'
	split 	pisa_country			, p(-) g(ave)
	gen		average=1 				if ave2 =="35" // flag only the 35-country OECD average
	drop 							if ave1=="OECD average" &	average !=1 // drop all other OECD averages
	replace	average=0 				if average==.
	gen 	nonbank=1 				if country==""
	replace	nonbank=0 				if nonbank==.
	replace country=ave1 			if country==""
	replace country="China"  		if pisa_country=="B-S-J-G (China)"
	drop 	pisa_country ave?
	reshape wide score, i(country year ptile subject) j(stat) str
	rename score* *
	rename _all, lower
	tempfile working
	save `working'

*	merge with OECD dummy
	merge m:1 code using "${data}/class", nogen keep(1 3) keepusing(group_OED)
	replace group_OED=0 if group_OED==.
	sort country subject ptile
	save `working', replace
	
***	generate dummy for countries below 25th percentile of OECD
	use `working', clear
	forvalues x=25(25)75 {
		gen				tempoecd = score if average==1 & ptile==`x'
		bysort subject: egen oecd_`x'=min(tempoecd)
		drop tempoecd
		}
	save `working', replace
	
***	indicate OECD countries we want to include in the graph
	use `working', clear
	gen		select_oecd=0
	replace select_oecd=1 if code=="MEX"
	replace select_oecd=1 if code=="FIN"
	replace select_oecd=1 if code=="KOR"
	replace select_oecd=1 if code=="TUR"
	replace select_oecd=1 if code=="DEU"
	replace select_oecd=1 if code=="IRL"
	replace select_oecd=1 if code=="JPN"
	gen 	select=0
	replace select=1 if select_oecd==1 
	replace select=1 if group_OED==0
	replace select=0 if code=="MAC"
	replace select=0 if code=="TWN"
	replace select=0 if code=="HKG"
	replace select=0 if code==""
	replace select=1 if average==1
	save `working', replace

***	distinguish between 25/75, 50, and 10/90
	use `working', clear
	gen plot_type =0
	replace plot_type=1 if ptile==50
	replace plot_type=2 if ptile==10
	replace plot_type=2 if ptile==90
	save `working', replace

***	drop extranneous countries
	use `working', clear
	drop if select==0
	drop if plot_type==2 // do not drop if you want to include 10/90
	save `working', replace

***	keep only countries we want to emphasize for chapter 0
	use `working', clear
	keep if subject=="mathematics"
	sort ptile score
	gen window_lo = score if code=="CRI" & ptile==75
	sum window_lo
	replace window_lo = `r(min)'
	gen window_hi = oecd_25
	gen drop_hi =.
	gen drop_lo =.
	levelsof country, local(countries)
	foreach country of local countries {
		sum score if ptile==25 & country=="`country'"
		replace drop_hi=`r(mean)' if country=="`country'"
		sum score if ptile==75 & country=="`country'"
		replace drop_lo=`r(mean)' if country=="`country'"
		}
		
sort country ptile
drop if drop_lo > window_lo & drop_hi < window_hi
save `working', replace

***	generate rank variables using medians for each subject
	use `working', clear
	keep if ptile==50
	* drop if average==1 // turn this on to make OECD average the left-most plot
	bysort subject: egen rank =rank(score), field
	keep subject country rank
	merge 1:m subject country using `working', nogen
	save `working', replace

*** archive data
	preserve
	keep if subject=="mathematics"
	keep country ptile score
	reshape wide score, i(country) j(ptile)
	lab var	score25 "25th percentile, PISA 2015 mathematics"
	lab var score50 "50th percentile, PISA 2015 mathematics"
	lab var score75 "75th percentile, PISA 2015 mathematics"
	lab var country "Country"
	wdrarchive
	restore
	

/*******************************************************************************
SET UP GRAPHING FIELDS
*******************************************************************************/

***	set up marker labels
	use `working', clear
	sum ptile
	gen mlabel=country if ptile==`r(min)'
	save `working', replace
	
***	generate corner points for interquartile range
	
	/* the order we want is:
		TL: rank==min & ptile==25
		TR: rank==min & ptile==75
		BR: rank==max & ptile==75
		BL: rank==max & ptile==25
	*/
	local boxmargin=.5
	expand=3 if average==1 & plot_type==0, gen(interquartile) // duplicate the 25th and 75th percentiles for the OECD average
	bysort rank interquartile subject (ptile): replace interquartile=_n if interquartile!=0 // replace indicator for half the expanded observations (replaces 1 with 2)
	sum rank
	replace rank=`r(min)'-`boxmargin' if interquartile==1 | interquartile==4
	replace rank=`r(max)'+`boxmargin' if interquartile==3 | interquartile==2
	save `working', replace

***	set up marker labels to serve as a key
		use `working', clear
		local leaderline_offset=.15
		local leaderline_length=.5
	*** identify the right-most plot
		gen rightmost=0
		sum rank if interquartile==0
		replace rightmost=1 if rank==`r(min)'
	***	keep only the rightmost & trim data
		keep if rightmost==1
		keep ptile rank score average select_oecd select plot_type subject
		gen legend_label_pos=0
	***	generate labels
		gen legend_label=""
		levelsof ptile, local(ptiles)
		foreach p of local ptiles {
			replace legend_label	="`p'th" 		if ptile==`p' & legend_label_pos ==0
			}
	***	expand once more to add the label of the labels (i.e. the legend title)
		expand=2 if ptile==75, gen(legend_title)
		replace legend_label="Percentile" if legend_title==1
	***	expand to create points for leader lines
		expand=2 if legend_title!=1, gen(leader_lines)
	***	adjust ranks to determine the x-coordinate values for leader lines
		replace rank=rank-`leaderline_offset'-`leaderline_length' 	if leader_lines==1
		replace rank=rank-`leaderline_offset' 						if leader_lines==0
	***	adjust 25th, 50th, 75th percentile labels
		replace legend_label_pos=3   if legend_title==0 
		replace legend_label_pos=1  if legend_title==1
	*** append and save
		append using `working'
		save `working', replace

***	set up grid lines
		use `working', clear
	***	summarize vars to get the appropriate xy values for the gridlines
		qui sum rank if legend_title==.
		local gridymin `r(min)' // this sets the top edge of the interquartile box
		local gridymax `r(max)' // this sets the bottom edge of the interquartile box
		sum score
		local gridxmin=100*round((`r(min)' / 100))
		local gridxmax=100*round((`r(max)' / 100))
	***	set up blank file
		keep subject
		duplicates drop
		gen score=.
		tempfile gridblank
		save `gridblank'
		tempfile gridbuild
		save `gridbuild'
	***	loop to establish x's
		forvalues x=`gridxmin'(50)`gridxmax' {
			use `gridblank', clear
			replace	score=`x'	
			append using `gridbuild'
			save `gridbuild', replace
			}
		drop if score==.
		save `gridbuild', replace
	***	double observations to establish y's
		use `gridbuild'
		gen 	plot_type=2
		expand=2, gen(expand)
		gen		rank=`gridymin' if expand==0
		replace	rank=`gridymax' if expand==1
		drop expand
		save `gridbuild', replace
	***	append to working dataset
		use `working', clear		
		append using `gridbuild'
		save `working', replace
	
***	set up alternative location for marker labels
	use `working', clear
	qui sum score if ptile==25
	gen alt_min=`r(min)'
	save `working', replace

	
/*******************************************************************************
SET LOCALS FOR GRAPHING
*******************************************************************************/

***	choose titles
	local mathematics_ttl "Mathematics score"

***	loop over these categories
	use `working', clear
	levelsof subject, local(subjects)
	levelsof country, local(countries)

***	loop to get graphing codes
	foreach country of local countries {
		use `working', clear
		sum average if country=="`country'" 
		local catnum=`r(mean)'+1 // the category number (catnum) determines the color
		/* interquartile lines */ local lines  `lines' 	(scatter score 	 rank if country=="`country'" & plot_type==0 & interquartile==0, c(l)  m(none) lw(medthick) lc("${wdrscheme`catnum'}")  ) 
		/* country labels      */ local labels `labels'	(scatter alt_min rank if country=="`country'" & plot_type==0 & interquartile==0, m(none) mlabel(mlabel) mlabsize(small) mlabc("${wdrscheme`catnum'}") mlabpos(7) mlabangle(45) )
		/* median points       */ local points `points'	(scatter score 	 rank if country=="`country'" & plot_type==1 & interquartile==0,  m(o) mlw(medthick) mlc("${wdrscheme`catnum'}") mfc(white) )
		}

***	loop for gridlines
	use `working', clear
	keep if plot_type==2
	levelsof score, local(scores)
	foreach score of local scores {
		local gridlines `gridlines' (scatter score rank  if plot_type==2 & score==`score', m(none) c(l) lc(gs2) lp(shortdash) lw(vthin) )
		}

/*******************************************************************************
GRAPH WITH LEGEND
*******************************************************************************/
	local leftsubjects mathematics
	foreach subject of local leftsubjects  {
		use `working', clear
			sort average subject  ptile interquartile rank 
		keep if subject=="`subject'"
		
	twoway ///
			(area score rank  if average==1 & interquartile !=0, fi(30) fcolor("$wdrscheme3") lcolor(white)) ///
	`gridlines' ///
	(scatter score rank if ptile==25 & legend_title==0, lc(gs0) c(l) m(none) lw(vthin)) ///	leader line for ptile==25
 	(scatter score rank if ptile==50 & legend_title==0, lc(gs0) c(l) m(none) lw(vthin)) ///	leader line for ptile==50
 	(scatter score rank if ptile==75 & legend_title==0, lc(gs0) c(l) m(none) lw(vthin)) ///	leader line for ptile==75
	`lines' `points' `labels' ///
	(scatter score rank if leader_lines==0 & legend_title==1 & legend_label_pos!=., m(none) mlabel(legend_label) mlabvpos(legend_label_pos) mlabel(legend_label) mlabsize(small) mlabc(black) mlabgap(*2)) /// add marker labels for legend (bottom of chart)
	(scatter score rank if leader_lines==1 & legend_title==0 & legend_label_pos!=., m(none) mlabel(legend_label) mlabvpos(legend_label_pos) mlabel(legend_label) mlabsize(small) mlabc(black) mlabgap(0)) /// add marker labels for legend (bottom of chart)
		`averageline' ///
				, ///
			legend(order(1) label(1 "OECD interquartile range")  r(1) symx(3) symy(3) region(c(none)m(t+20 )) size(small)) ///
			yscale(r(300 600) noline ) ///
			xscale(noline reverse) ///
			xlabels("") ///
			ylabels(300(100)600, angle(horizontal) tlc(gs15) nogrid glc(gs15) glw(thin) notick labsize(small) labgap(0) ) ///
			title("") ///
			xtitle("") ///
			plotregion(c(none)m(t-2 b-2)) ///
			graphregion(c(white)lw(thick)lc(white)m(r+5 b-5 t+1 l-1)) ///
			ytitle("``subject'_ttl'", bexpand color(black) size(small)  ) ///
			name(`subject'_with, replace)
		}
		
/*******************************************************************************
COMBINE GRAPHS AS NEEDED
*******************************************************************************/
	
	graph display mathematics_with, xsize(6.5) ysize(4) 
	
	wdrexport , ///
		title(In several countries the 75th percentile on PISA performs below the 25th percentile of the OECD average) ///
		subtitle(Performance of 25th, 50th, and 75th percentiles in 2015 PISA mathematics assessment, selected countries) ///
		source(WDR 2018 team, using data from Programme for International Student Assessment (PISA) collected in 2015 (OECD 2016).) ///
		chapter(0) figure(2) 
	
	exit	
	
	
