/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREP DATA
*******************************************************************************/

***	set up blank file
	clear
	gen class=.
	tempfile working
	save `working'
	
***	import data and calculate stats for each subject
	foreach subject in math lang {
		use "${data}/ms_levels_`subject'", clear
		cap rename hindi* lang*
		cap drop if class<6
		bysort class: egen `subject'_p25 	= pctile(`subject'level),p(25)
		bysort class: egen `subject'_mean 	= mean(`subject'level)
		bysort class: egen `subject'_p75 	= pctile(`subject'level),p(75)
		keep class `subject'_*
		duplicates drop
		merge 1:1 class using `working', nogen
		save `working', replace
		}

***	archive data
foreach subject in mathematics language {
	preserve
	rename lang_* *language
	rename math_* *mathematics
	reshape long p25 mean p75, i(class) j(subject) str
	gen expected=class
	rename class grade
	lab var  grade "Enrolled grade"
	lab var subject "Subject"
	lab var p25 "25th percentile, assessed performance"
	lab var p75 "75th percentile, assessed performance"
	lab var mean "Mean, assessed performance"
	lab var expected "Expected performance"
	order subject, first
	sort subject grade
	keep if subject=="`subject'"
	wdrarchive, title(`subject')
	restore
	}

/*******************************************************************************
GRAPH
*******************************************************************************/

use `working', clear

***	calculate positions of labels
	sum class
	local maxclass=`r(max)'
	local maxclassplus = `maxclass'+.1
	local markeropts placement(e) just(left) bexpand
	
	***	labels for graphs using percentiles
		local 	lang_addedtext_ptile text(`maxclass' `maxclassplus' "Expected performance"									, `markeropts' color("$wdrscheme3"))
		sum		lang_p75 if class==`maxclass'
		local 	lang_addedtext_ptile `lang_addedtext_ptile' text(`r(mean)' `maxclassplus' "75th percentile" 				, `markeropts' color("$wdrscheme1"))
		sum		lang_mean if class==`maxclass'
		local 	lang_addedtext_ptile `lang_addedtext_ptile' text(`r(mean)' `maxclassplus' "Average assessed" "performance"	, `markeropts' color("$wdrscheme1"))
		sum		lang_p25 if class==`maxclass'
		local 	lang_addedtext_ptile `lang_addedtext_ptile' text(`r(mean)' `maxclassplus' "25th percentile" 				, `markeropts' color("$wdrscheme1"))
	
***	set gridlines
	forvalues y=3(1)9 {
		local xline `xline' yline(`y', lc(gs12) lw(vthin) lp(shortdash))
		}
		
***	set options
	local subjects math lang
	local math_ylabs 3(1)9, angle(h) nogrid notick labgap(*2)
	local lang_ylabs 3(1)9, angle(h) nogrid notick labgap(*2)
	local math_tit "a. Mathematics"
	local lang_tit "b. Language"
	local math_ytit "Grade-level performance"
	local lang_ytit "Grade-level performance"

***	loop for graphs using percentiles
	foreach subject of local subjects {
		twoway ///
			(function y=x, range(6 9) lc("$wdrscheme3") lp(solid) lw(thick)) ///
			(line `subject'_p25 `subject'_mean `subject'_p75 class, sort ///
				lc("$wdrscheme1" "$wdrscheme1" "$wdrscheme1") ///
				lp(shortdash solid shortdash) ///
				lw(vthick thick vthick) ///
				) ///
				, ///
				``subject'_addedtext_ptile' ///
				`xline' ///
				graphregion(c(white)lc(white)lw(thick) ) ///
				plotregion(m(b-10 t-10 r-1 l-1)) ///
				ytitle(``subject'_ytit', size(medium) height(4)) ///
				xtitle("Enrolled grade", size(medium) margin(t+2)) ///
				legend(off) ///
				yscale(noline r(3 9)) ///
				xscale(noline) ///
				xlabels(, tlc(gs12) tlw(vthin)) ///
				ylabel(``subject'_ylabs') ///
				title({bf:``subject'_tit'}, just(left) bexpand color(black) size(medium)) ///
				name(`subject'_ptile)
		}

***	combine
	graph combine math_ptile lang_ptile, ycommon xcommon imargin(3 0 0 0) iscale(1.05) graphregion(c(white)lc(white)lw(thick)margin(r+35)) xsize(4.3) ysize(3)
	graph drop math_ptile lang_ptile
	
/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(Students often learn little from year to year, and early learning deficits are magnified over time) ///
	subtitle(Assessed grade-level performance of students relative to enrolled grade, New Delhi (2015)) ///
	source(WDR 2018 team, using data from Muralidharan, Singh, and Ganimian (2016).) ///
	chapter(0) figure(4) 

exit
	
