/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
Figure 0.4 minimum proficiency
*******************************************************************************/

***	WDR settings
	include wdrsettings

/*******************************************************************************
PREP DATA
*******************************************************************************/

***	load & trim data
	use $data/AAP_2015_panel, clear
	qui keep if level==1
	qui keep if gender==3
	qui keep if subject==1 | subject==2
	
	bysort country subject: egen maxyr=max(year)
	qui keep if year==maxyr
	qui keep country subject minimum_proficiency
	decode subject, gen(sub)
	qui replace sub = trim(sub)
	drop subject

***	reshape data
	qui reshape wide minimum_proficiency, i(country) j(sub)  str
	rename minimum_proficiency* *

***	label vars
	lab var mathematics "mathematics, minimum proficiency (% of students)"
	lab var reading "reading, minimum proficiency (% of students)"

***	merge with idvars
	qui merge 1:1 country using "${data}/class", keepusing(code incomegroup category) keep(3) nogen

***	format vars
	format mathematics reading %3.0f
	
***	view minimum proficiency rates for select countries
	gsort incomegroup -mathematics 
	list incomegroup country mathematics reading, sepby(incomegroup)

***	report select countries that appear in text
	qui gen 	dum_report=0
	qui replace dum_report=1 if code=="JPN"
	qui replace dum_report=1 if code=="FRA"
	qui replace dum_report=1 if code=="NZL"
	qui replace dum_report=1 if code=="MLI"
	qui replace dum_report=1 if code=="NIC"
	qui replace dum_report=1 if code=="PHL"
	qui replace dum_report=1 if code=="MEX"
	list incomegroup country mathematics reading if dum_report==1, sepby(incomegroup)

***	decode
	decode incomegroup, gen(ig)
	decode category, gen(rg)

***	create tempfile and merge file
	tempfile working
	save `working', replace
	clear
	gen category=.
	tempfile build
	save `build'
	
***	collapse, by income group and region
	local i=0
	foreach group in ig rg {
		local ++i
		use `working', clear
		collapse (p50) mathematics reading , by(`group')
		rename `group' group
		gen category=`i'
		append using `build'
		save `build', replace
		}

***	collapse for world average	
	local ++i
	use `working', clear
	collapse (p50) mathematics reading
	gen group="World"
	gen category=`i'
	append using `build'
	save `build', replace
	
***	drop duplicate high-income category
	drop if category==2 & group=="High income"
	drop if category==3 // maybe reverse?
	
***	archive
	order group, first
	sort mathematics
	lab var mathematics "Median percentage of students above minimum sufficiency, mathematics"
	lab var reading "Median percentage of students above minimum sufficiency, reading"
	lab var group "Income group or region"
	preserve
	drop category
	wdrarchive
	restore
	
***	generate sort category
	bysort category (mathematics): gen sort=_n
	
*** regen sort vars
	sort category sort
	replace sort=_n

***	split labels into two lines
	splitstring group
	
***	encode group
	egen grp= axis(sort), label(group)

***	display stats
	sort grp
	list group mathematics reading, sepby(category)
	
/*******************************************************************************
GRAPH
*******************************************************************************/

***	pull labels
	levelsof grp, local(grps)
	foreach grp of local grps {
		sort grp
		local l1 =strtrim("`=group_line1[`grp']'")
		local l2 =strtrim("`=group_line2[`grp']'")
		local relabel `relabel' `grp' `""`l1'" "`l2'""'
		}
		
***	set graph options
	local lsize medsmall
	local tsize medium
	
***	graph
	graph bar mathematics reading, ///
		over(grp, relabel(`relabel') label(labsize(`lsize'))) ///
		over(category, label(nolabel) gap(*1.05)) ///
			nofill ///
		xsize(6.5) ysize(2.75) ///
		ylabels(0(20)100,angle(h) notick glc(gs2) glp(shortdash) glw(thin) labsize(`tsize')) ///
		graphregion(c(white)lc(white)lw(thick) m(l-3 r-1 b-2 t-4)) ///
		yscale(noline) ///
		ytitle("Percentage of students", size(`tsize')) ///
		bar(1, color("$wdrscheme1")) ///
		bar(2, color("$wdrscheme4")) ///
		legend( ///
			region(c(none)) ///
			symx(4) symy(4) ///
			label(1 "Mathematics") ///
			label(2 "Reading") ///
			) ///
		outergap(0) ///
		name(aap_bar, replace)

/*******************************************************************************
EXPORT
*******************************************************************************/

wdrexport , ///
	title(The percentage of primary school students who pass a minimum proficiency threshold is often low) ///
	subtitle(Median percentage of students in late primary school who score above a minimum proficiency level on a learning assessment, by income group and region) ///
	source(WDR 2018 team, using “A Global Data Set on Education Quality” made available to the team by Nadir Altinok, Noam Angrist, and Harry Athony Patrinos, 2017.) ///
	note(Bars show the unweighted cross-country median within country grouping. Regional averages exclude high-income countries. India and China are among the countries excluded for lack of data. Minimum proficiency in mathematics is benchmarked to the Trends in International Mathematics and Science Study (TIMSS) assessment and in reading to the Progress in International Reading Literacy Study (PIRLS) assessment. Minimum proficiency in mathematics means that students have some basic mathematical knowledge such as adding or subtracting whole numbers, recognizing familiar geometric shapes, and reading simple graphs and tables (Mullis and others 2016). Minimum proficiency in reading means that students can locate and retrieve explicitly stated detail when reading literary texts and locate and reproduce explicitly stated information from the beginning of informational texts (Mullis and others 2012).) ///
	chapter(0) figure(5)

exit
