/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
gaps in school completion rates, by family background
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/
	
***	choose data to keep
	local cutoffyear 2005 // choose later year when Deon copies data
	#delimit ;
	local keepvars
		aAll_6 
		aUrban_6
		aRural_6
		aMale_6
		aFemale_6
		aQuint1_6
		aQuint5_6
		aQuint1x_6
		aQuint5x_6
		; 
	#delimit cr
	
***	load data
	use "${data}\Filmer 2016 educational attainment by background", clear
	drop if subnational==1
	bysort country (year): keep if _n==_N // keep latest
	drop region
	merge 1:1 code using "${data}/class", nogen keep(3)
		
***	trim data to include only reasonable recent surveys and vars of interest
	drop if year <`cutoffyear' 
	keep country code year region incomegroup group* `keepvars'
	replace	aQuint1_6 = aQuint1x_6 if aQuint1_6==.
	replace	aQuint5_6 =	aQuint5x_6 if aQuint5_6==.
	drop aQuint1x_6 aQuint5x_6
	
***	choose grades
	*local grades 6
	
***	pull min/max years
	sum year
	local minyear=`r(min)'
	local maxyear=`r(max)'
	
***	calculate values for droplines
	gen location_6 	= aUrban_6 -	aRural_6 
	label var location_6 "Gap between Urban and Rural, grade 6"
	gen gender_6 		= aMale_6	-	aFemale_6
	label var gender_6  "Gap between Male and Female, grade 6"
	gen income_6		= aQuint5_6 - aQuint1_6
	label var income_6 "Gap between Richest and Poorest Quintile, grade 6"
	gen all_6			= aAll_6
	label var all_6	 "Overall grade 6 completion rate"
	
	
***	trim the data
	keep country income_* location_* gender_* all_*
	
***	rescale the data
	ds country , not
	foreach var in `r(varlist)' {
		replace `var' = `var'*100
		}

***	save data
	tempfile working
	save `working'
	
/*******************************************************************************
GRAPH
*******************************************************************************/	

***	load data
	use `working', clear
	
***	break ytitles into two lines
	local ytit_location "Percentage-point gap between" "Urban and Rural"
	local ytit_gender	"Percentage-point gap between" "Male and Female"
	local ytit_income 	"Percentage-point gap between" "Richest and Poorest Quintile"
	
***	set panel titles
	local  ttl_income 	"Richest - Poorest"
	local ttl_location	"Urban - Rural"
	local  ttl_gender	"Male - Female"
	
***	tokenize alphabet for panel titles
	tokenize `c(alpha)'
	
***	graph
	local i=0
	foreach var in income location gender  {
		local ++i
		twoway dropline `var'_6 all_6, ///
			name(g_`var'_6, replace) ///
			m(O) mfc(white) mc("$wdrscheme5") lc("$wdrscheme5") lw(vvthin) mlw(medthick) ///
			graphregion(c(white)lw(thick)lc(white)) ///
			ylabel(, angle(h) nogrid labsize(medium)) ///
			xlabel(, labsize(medium)) ///
			yline(0, lc(gs8) lw(thin)) ///
			ytitle("`ytit_`var''",size(medsmall) margin(r-1)) ///
			xtitle(,size(medsmall)) ///
			aspectratio(1) ///
			title("{bf:``i''. `ttl_`var''}", bexpand just(left) size(medium) c(black))
		local combo6 `combo6' g_`var'_6
		}
		

***	combine panels
	 graph combine `combo6', ///
		ycommon r(1) graphregion(c(white)lw(thick)lc(white) margin(l-5 r-2 b-6 t-8)) ///
		xsize(6.5) ysize(2.05) com iscale(1.3) name(combined_6, replace)
	
***	drop individual pnaels
	graph drop `combo6'

	
/*******************************************************************************
EXPORT TWO COPIES
*******************************************************************************/	

***	export figure 2.5
	use `working', clear
	wdrarchive
	wdrexport , ///
		title(School completion is always higher for children from wealthier families and urban settings, whereas gender gaps are more mixed) ///
		subtitle(Gaps in grade 6 completion rates (percent) for 15-19-year-olds, by wealth, location, and gender) ///
		source(WDR 2018 team, using data from Filmer (2016).) ///
		note(The data presented are the latest available by country, 2005-14. Each vertical line indicates the size and direction of the gap for a country.) ///
		chapter(2) figure(5)

***	export figure 0.6
	use `working', clear
	wdrarchive
	wdrexport , ///
		title(School completion is always higher for children from wealthier families and urban settings, whereas gender gaps are more mixed) ///
		subtitle(Gaps in grade 6 completion rates (percent) for 15-19-year-olds, by wealth, location, and gender) ///
		source(WDR 2018 team, using data from Filmer (2016).) ///
		note(The data presented are the latest available by country, 2005-14. Each vertical line indicates the size and direction of the gap for a country.) ///
		chapter(0) figure(6)
		
exit
