/*******************************************************************************
Bradley Larson (BLarson@worldbank.org)
World Development Report 2018: Education
*******************************************************************************/

***	WDR settings
	include wdrsettings
	
/*******************************************************************************
PREPARE DATA
*******************************************************************************/

***	load data
	use "${data}/EdStats LLECE SACMEQ spending and learning", clear
	order _all, alpha
	order country test, first
	
***	archive data
	preserve
	drop *_usd
	wdrarchive
	restore
		
***	identify tests
	levelsof test, local(tests)
	
***	gen time stamp for min and max years
	bysort test country (year_score): gen time=_n-1
	
***	store years in temp file
	preserve
	drop score spending*
	reshape wide year_spending year_score, i(country test) j(time)
	tempfile span_years
	save `span_years'
	restore

***	drop year from main file
	drop year*
	
***	reshape wide
	reshape wide spending_ppp spending_usd score, i(country test) j(time) 

***	identify data variables
	ds country test, not
	local actual_values `r(varlist)'
	
***	calculate relative changes
	foreach item in spending_ppp spending_usd score {
		foreach node in 0 1 {
			gen `item'`node'difference=`item'`node'-`item'0
			gen `item'`node'relative=((`item'`node'/`item'0)-1)*100
				}
				}
	
***	rename variables representing levels
	rename (`actual_values)') =levels
	
***	reshape long
	reshape long spending_ppp0 spending_ppp1 spending_usd0 spending_usd1 score0 score1 , i(country test) j(stat) str

***	generate year variable
	merge m:1 country test using `span_years', nogen

***	save data for graphing
	tempfile working
	save `working'

/*******************************************************************************
GRAPH
*******************************************************************************/

***	set labels
	foreach test of local tests {
		local ytit_`test'_score_levels "Average `test' score"
		local ytit_`test'_spending_levels "Spending per student, PPP"
		local ytit_`test'_score_relative "Change in average" "`test' score (%)"
		local ytit_`test'_spending_relative "Change in spending" "per student (%)"
		}
		
***	choose colors
	local Peru_color 1
	local Lesotho_color 1
	local Guatemala_color 3
	local Malawi_color 3
	local Paraguay_color 2
	local Kenya_color 2
	
***	establish graphing commands
foreach stat in levels  { 
	use `working', clear
	drop *_usd?
	keep if stat=="`stat'"
	drop stat
	
	reshape long spending_ppp score year_spending year_score, i(country test) j(period)
	
	gen countrylabel=country if period==1
	
	foreach test of local tests {
		local  `test'_spending_scat
		local `test'_score_scat 
		local spendinggraphs
		local scoregraphs
		
		preserve
		keep if test=="`test'"

		levelsof country, local(countries)
		local i=0
		foreach country of local countries {
			local ++i
			local `test'_spending_scat 	``test'_spending_scat' 	(scatter spending year_spending 	if country=="`country'", c(l) m(O) mfc(white) mlc("${wdrscheme``country'_color'}") lc("${wdrscheme``country'_color'}") mlw(medthick) lw(medthick) mlabel(countrylabel) mlabc("${wdrscheme``country'_color'}"))
			local `test'_score_scat 	``test'_score_scat' 	(scatter score year_score 			if country=="`country'", c(l) m(O) mfc(white) mlc("${wdrscheme``country'_color'}") lc("${wdrscheme``country'_color'}") mlw(medthick) lw(medthick) mlabel(countrylabel) mlabc("${wdrscheme``country'_color'}"))
			}
		restore
			}
		

***	set graph options
	local gopts ///
	legend(off) ///
		xtitle("Year") ///
		ylabel(#5, angle(h) nogrid) ///
		graphregion(c(white)lc(white)lw(thick)margin(r+10 l-2)) 
	local aspectratio 1.5
		
***	set labels
	local LLECE_score_labs 2006 2010 2014
	local SACMEQ_score_labs 2000 2005 2010
	local SACMEQ_spend_labs 2000 2005 2010
	local LLECE_spend_labs 2006 2010 2014


foreach test of local tests {		

	twoway ``test'_spending_scat', 	///
		`gopts' ///
		ytitle("`ytit_`test'_spending_`stat''") 	///
		xscale(range(``test'minyr' ``test'maxyr'))	///
		xlabel(``test'_spend_labs') ///
		aspect(`aspectratio') ///
		name(`test'_spending, replace) 
		
	twoway ``test'_score_scat', 	///
		`gopts' ///
		ytitle("`ytit_`test'_score_`stat''") 	///
		xscale(range(``test'minyr' ``test'maxyr'))	///
		xlabel(``test'_score_labs') ///
		aspect(`aspectratio') ///
		name(`test'_score, replace)
	
	local spendinggraphs `spendinggraphs' `test'_spending 
	local scoregraphs `scoregraphs' `test'_score

}

***	combine graphs and adjust scales
	local ttlopts bexpand just(left) color(black) margin(l+3) size(small)
	graph combine `spendinggraphs', c(1)  graphregion(c(white)lc(white)lw(thick)) name(spending_graphs, replace) title("a. Changes in public education" "    spending", `ttlopts')
	graph combine  `scoregraphs', c(1)  graphregion(c(white)lc(white)lw(thick)) name(score_graphs, replace)		title("b. Changes in grade 6 learning"  "    outcomes", `ttlopts' )
	graph combine 	spending_graphs score_graphs, r(1)  graphregion(c(white)lc(white)lw(thick) margin(b-6 l-4 t-4 r-3)) scale(1.4) name(`stat'_graph, replace) xsize(4) ysize(4)
	graph drop `spendinggraphs' `scoregraphs' spending_graphs score_graphs
	}

/*******************************************************************************
EXPORT
*******************************************************************************/

	wdrexport , ///
		title(The relationship between changes in public education spending and student learning is weak) ///
		subtitle(Changes in public education spending (2000–2007, 2006–13) and in sixth-grade mathematics outcomes (2000–2007, 2006–13), selected countries) ///
		source(WDR 2018 team, using data from UIS (2017) for spending, and World Bank (2017) for student learning.) ///
		note(Spending, per student, is reported in purchasing power parity (PPP) U.S. dollars. Student learning data are derived from data collected by the Southern and Eastern Africa Consortium for Monitoring Educational Quality and the Latin American Laboratory for Assessment of the Quality of Education.) ///
		chapter(6) figure(2) spotlight
				
exit
