/*******************************************************************************
Bradley Larson (Larson.Brad@gmail.com)

chartreport -- compile a word document with all figures generated for selected
chapters and exported using wdrexport.
*******************************************************************************/


capture program drop wdrcharts
program define wdrcharts, rclass
version 14

/*******************************************************************************
INSTALL PROGRAMS
*******************************************************************************/
	cap ssc install markdoc
	cap ssc install weaver
	cap ssc install statax
	
/*******************************************************************************
BASIC OPTIONS
*******************************************************************************/
	preserve
	include wdrsettings
	cd $root
	clear
			
/*******************************************************************************
GENERATE A FILE NAME FOR THE REPORT USING CURRENT DATE AND TIME
*******************************************************************************/	

***	filename is a concatenation of current date and time to avoid copying over files
	tokenize `c(Mons)'
	local ctime =substr(subinstr("`c(current_time)'",":","",.),1,4)
	local cdate =trim("`c(current_date)'")
	local cdate =subinstr("`cdate'"," ","_",.)
	forvalues x=1/12 {
		local cdate =subinstr("`cdate'","``x''","`x'",.)
		}
	local day   =substr("`cdate'",1,strpos("`cdate'","_")-1)
	local cdate =subinstr("`cdate'","`day'_","",1)
	local month =substr("`cdate'",1,strpos("`cdate'","_")-1)
	if `month' < 10 {
		local month "0`month'"
		}
	if `day' < 10 {
		local month "0`day'"
		}
	local year  =substr("`cdate'",length("`cdate'")-1,2)

***	set chart report name
	local chartreportname "`year'`month'`day'_`ctime'_WDR2018_Figures"
	noi di `"`chartreportname'"'
		
/*******************************************************************************
SET UP A BLANK FILE AS FOUNDATION FOR COMPILING ALL FIGURE METADATA
*******************************************************************************/

***	clear
	clear all

***	generate blank var
	qui gen chapternumber=.
	
***	save temp
	tempfile	meta
	qui save		`meta'

/*******************************************************************************
IDENTIFY FILES TO COMPILE
*******************************************************************************/

***	navigate to the output folder
	qui cd $output

***	identify all the files we need to compile
	local outputs : dir . file "`x'*meta.dta"
	
***	compile metadata
	foreach metafile of local outputs {
		use "`metafile'", clear
		qui append using `meta'
		qui save `meta', replace
		}

***	export metadatafile
	gsort -figureclass chapternumber figurenumber
	cap drop outputpath
	cap drop figureclass
	cap drop chapternumber
	cap drop figurenumber
	cap drop root
	export delimited "`chartreportname'_fullmetadata.csv", replace

***	identify all variables in metadata file
	use `meta', clear
	ds
	local metadatavars `r(varlist)'
/*
***	concatenate chapter and figure number and call it "root"
	qui tempvar 	chapno figno
	qui tostring 	figurenumber, gen(`figno') format(%4.2g) force
	replace `figno'="O" if `figno'=="0"  // replace chapter 0 with chapter O for observations
	qui tostring	chapternumber, gen(`chapno')
	qui gen root	= `chapno' + "-" + subinstr(`figno',".","_",.)
	replace root ="S"+root	if figureclass =="spotlight"
	qui drop `chapno' `figno'
	qui save `meta', replace
*/

***	pull roots for each class of figures
	foreach figureclass  in standard box spotlight {
		use `meta', clear
		replace figurenumber=figurenumber*10
		keep if figureclass=="`figureclass'"
		levelsof chapternumber, local(`figureclass'_chapters)
		foreach chapter of local `figureclass'_chapters {
			levelsof figurenumber if chapter==`chapter', local(`figureclass'`chapter'figures)
			foreach figure of local `figureclass'`chapter'figures {
				levelsof root if chapternumber==`chapter' & figurenumber==`figure', local(root) clean
				local `figureclass'roots`chapter' ``figureclass'roots`chapter'' `root'
				}
				}
				}

/*******************************************************************************
LOG 
*emf png ps pdf eps tif wmf
*******************************************************************************/

***	open log
	set linesize 155
	cap qui log close	
	qui log using `chartreportname', replace smcl

/**/ txt "@@@pagebreak"
/**/ foreach figureclass in standard box spotlight {
/**/ use `meta', clear
/**/	qui keep if figureclass=="`figureclass'"
/**/	if "`figureclass'"=="box" {
/**/ 		txt "#Box Figures"
/**/		local stub "Box figure"
/**/		}
/**/	if "`figureclass'"=="spotlight" {
/**/ 		txt "#Spotlight Figures"
/**/		local stub "Figure"
/**/		}
/**/ foreach chapter of local `figureclass'_chapters { // cycle through chapters
******	determine if there are figures in this chapter
/**/	local figcnt : word count ``figureclass'roots`chapter''
/**/		if `figcnt'>0 {
/**/ 	txt "_newline(8)"
/**/	if "`figureclass'"=="standard" {
/**/		if `chapter'==0 {
/**/			txt "#Overview"
/**/			}
/**/		else {
/**/ 			txt "#Chapter `chapter'"
/**/			}
/**/		local stub "Figure"
/**/		}
/**/	foreach root of local `figureclass'roots`chapter' {
/**/ 		use "`stub' `root' meta", clear
/**/ 	foreach var of local metadatavars {
/**/ 		local `var' `=`var'[1]'
/**/ 		}
/**/ 		txt "###`reference'  `title'"
/**/ 		if "`subtitle'" !="" {
/**/ 			txt "_`subtitle'"_
/**/ 			}
/**/ 		img using "`stub' `root'.emf"
/**/		if "`source'" 	!="" {
/**/			txt "__Source:__ `source'"
/**/			}
/**/		if "`note'" 	!="" {
/**/			txt "__Note:__ `note'"
/**/			}
*******	insert a page break code to be globally replaced with page break
/**/		txt "@@@pagebreak"
/**/ 			}
/**/		}
/**/ 			}
/**/ 		}
******	clear memory and locals
/**/ 		clear all
/**/ 		foreach var of local metadatavars {
/**/ 			local `var' ""
/**/	}

/*** close out the file ***/
	qui log c

/*******************************************************************************
SAVE LOG AND CONCLUDE
*******************************************************************************/
	
*** announce what has been compiled 
	noi di _newline (2) as result "{p 0 0 2}The following files have been compiled:{p_end}"

***	move files around and translate to doc
	qui markdoc `chartreportname', replace export(docx) toc
	erase `chartreportname'.smcl
	copy `chartreportname'.docx "$reports\`chartreportname'.docx"
	erase `chartreportname'.docx
	copy `chartreportname'_fullmetadata.csv "$reports\`chartreportname'_fullmetadata.csv
	erase `chartreportname'_fullmetadata.csv
	
***	provide links
	local chartreportlink "${reports}\`chartreportname'.docx"
	local metadatalink "${reports}\`chartreportname'_fullmetadata.csv"
	noi di as text _c _col(4) "Figures:" as result _col(15) `"{bf:{browse "`chartreportlink'"}}"' _newline
	noi di as text _c _col(4) "Metadata:" as result _col(15) `"{bf:{browse "`metadatalink'"}}"' _newline
	noi di _newline
***	return to origin folder and save
	restore

	qui cd `"`returnfolder'"'
	end


